@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,17 +69,52 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
+
 #ifndef __FK_ANGLE_HEADER__
 #define __FK_ANGLE_HEADER__
 
+
+//! オイラー角を表すクラス
+/*!
+ *	オイラー角は、3次元での姿勢を表す方法の一つで、
+ *	空間中の全ての姿勢を表現することが可能です。
+ *	FK におけるオイラー角は Z-X-Y 座標系を意味します。
+ *	ヘディング角を h、ピッチ角を p、バンク角を b としたとき、
+ *	このオイラー角は以下の回転変換と同意です。
+ *	\f[
+ *		R_y(-h) \cdot R_x(p) \cdot R_z(-b)
+ *	\f]
+ *	角度の単位はすべて弧度法(ラジアン)です。
+ */
+
 class fk_Angle {
  public:
-	double h, p, b;
-	fk_Angle(double = 0.0, double = 0.0, double = 0.0);
 
-	void set(double, double, double);
+	double h; //!< ヘディング角
+	double p; //!< ピッチ角
+	double b; //!< バンク角
+
+	//! コンストラクタ
+	/*!
+	 *	\param[in]	h	ヘディング角
+	 *	\param[in]	p	ピッチ角
+	 *	\param[in]	b	バンク角
+	 */
+	fk_Angle(double h = 0.0, double p = 0.0, double b = 0.0);
+
+	//! 設定用関数
+	/*!
+	 *	\param[in]	h	ヘディング角
+	 *	\param[in]	p	ピッチ角
+	 *	\param[in]	b	バンク角
+	 */
+	void set(double h, double p, double b);
+
+#ifndef FK_DOXYGEN_USER_PROCESS
 	void Print(void);
 	void Print(std::string);
+#endif
+
 };
 
 #endif // !__FK_ANGLE_HEADER__
