@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -76,6 +74,17 @@
 
 #include <FK/Curve.h>
 
+//! Bezier曲線を生成、管理するクラス
+/*!
+ *	このクラスは、形状として Bezier 曲線を制御する機能を提供します。
+ *	初期状態は 3 次式で、制御点が全て原点にある状態となります。
+ *	現状では、2,3,4次式のいずれかのみしか生成できません。
+ *	\remarks
+ *	本クラスは現在ベータ機能としての位置づけであり、
+ *	ユーザーズマニュアルには記載されていません。
+ *	また、今後のバージョンアップにおいて仕様が変更される可能性があります。
+ */
+
 class fk_BezCurve : public fk_Curve {
 
 	int						deg;
@@ -83,26 +92,74 @@ class fk_BezCurve : public fk_Curve {
 
  public:
 
+	//! コンストラクタ
 	fk_BezCurve(void);
+
+	//! デストラクタ
 	~fk_BezCurve();
 
-	// 初期化 
+	//! 初期化用関数
+	/*!
+	 *	この関数は、曲線を初期状態(3次式、全ての制御点が原点にある状態)にします。
+	 */
 	void			init(void);
 
-	// 次数設定 
-	bool			setDegree(int);
-	// 制御点設定 
-	bool			setCtrl(int, const fk_Vector &);
+	//! 次数設定関数
+	/*!
+	 *	この関数は、曲線の次数を設定します。
+	 *	現状では、2,3,4のいずれかのみ以外は設定できません。
+	 *	次数が増加した場合は、これまで保持されていた制御点位置ベクトルは保持され、
+	 *	新たな制御点は原点に配置されます。
+	 *	次数が減少した場合は、末尾の制御点が消失しますが、
+	 *	存続している制御点の位置ベクトルは保持されます。
+	 *	\param[in] deg 次数
+	 *	\return 次数設定に成功した場合 true、失敗した場合 false を返します。
+	 */
+	bool			setDegree(int deg);
 
-	// 次数参照 
+	//! 制御点設定関数
+	/*!
+	 *	曲線の制御点位置ベクトルを設定します。
+	 *	\param[in] ID 設定する制御点の ID。先頭は 0 になります。
+	 *	\param[in] pos 制御点位置ベクトル
+	 *	\return 設定に成功した場合 true、失敗した場合 false を返します。
+	 */
+	bool			setCtrl(int ID, const fk_Vector &pos);
+
+	//! 次数参照関数
+	/*!
+	 *	曲線の次数を参照します。
+	 *	\return 次数
+	 */
 	int				getDegree(void);	
-	// 制御点参照 
-	fk_Vector		getCtrl(int);
 
-	// 曲線点座標値算出 
-	fk_Vector		pos(double);
-	// 曲線微分ベクトル算出 
-	fk_Vector		diff(double);
+	//! 制御点参照関数
+	/*!
+	 *	曲線の制御点位置ベクトルを参照します。
+	 *	\param[in] ID 制御点 ID
+	 *	\return 制御点位置ベクトル。IDが不正だった場合、零ベクトルを返します。
+	 */
+	fk_Vector		getCtrl(int ID);
+
+	//! 曲線算出関数
+	/*!
+	 *	パラメータに対応する曲線上の点の位置ベクトルを返します。
+	 *	Bezier 曲線の幾何的定義ではパラメータの定義域は 0 から 1 までですが、
+	 *	本関数はそれ以外の範囲であっても式の演算結果を返します。
+	 *	\param[in] t 曲線上のパラメータ
+	 *	\return 曲線上の点の位置ベクトル
+	 */
+	fk_Vector		pos(double t);
+
+	//! 曲線1階微分ベクトル算出関数
+	/*!
+	 *	パラメータに対応する曲線上の点の1階微分ベクトルを返します。
+	 *	Bezier 曲線の幾何的定義ではパラメータの定義域は 0 から 1 までですが、
+	 *	本関数はそれ以外の範囲であっても式の演算結果を返します。
+	 *	\param[in] t 曲線上のパラメータ
+	 *	\return 曲線上の点の1階微分ベクトル
+	 */
+	fk_Vector		diff(double t);
 };
 
 #endif	// __FK_BEZCURVE_HEADER__
