@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -76,15 +74,95 @@
 
 #include <FK/IndexFace.h>
 
+//! 直方体を生成、管理するクラス
+/*!
+ *	このクラスは、形状として直方体を制御する機能を提供します。
+ *	直方体は、原点の物体の中心が来るように配置されます。
+ *	従って、(x, y, z) という大きさで直方体を生成した場合、
+ *	各頂点の位置ベクトルは以下のようになります。
+ *	- (x/2, y/2, z/2)
+ *	- (-x/2, y/2, z/2)
+ *	- (-x/2, -y/2, z/2)
+ *	- (x/2, -y/2, z/2)
+ *	- (x/2, y/2, -z/2)
+ *	- (-x/2, y/2, -z/2)
+ *	- (-x/2, -y/2, -z/2)
+ *	- (x/2, -y/2, -z/2)
+ *
+ *	このクラスは、実質的には fk_IndexFaceSet クラスの派生クラスであり、
+ *	生成後に fk_IndexFaceSet クラスの機能によって頂点を移動することが可能です。
+ *
+ *	\sa fk_IndexFaceSet, fk_Shape, fk_Model
+ */
+
 class fk_Block: public fk_IndexFaceSet {
  public:
-	fk_Block(double = 1.0, double = 1.0, double = 1.0);
+
+	//! コンストラクタ
+	/*!
+	 *	引数として、各軸方向の幅を入力できます。
+	 *	引数を省略した場合は、辺長が 1 の立方体を生成します。
+	 *
+	 *	\param[in]	x	x方向の辺長
+	 *	\param[in]	y	y方向の辺長
+	 *	\param[in]	z	z方向の辺長
+	 */
+	fk_Block(double x = 1.0, double y = 1.0, double z = 1.0);
+
+	//! デストラクタ
 	~fk_Block();
-	void	setSize(double, double, double);
-	void	setSize(double, fk_Axis);
-	void	setScale(double);
-	void	setScale(double, fk_Axis);
-	void	setScale(double, double, double);
+
+	//! 各辺長設定関数
+	/*!
+	 *	直方体の各軸方向の辺長を一括して設定します。
+	 *
+	 *	\param[in]	x	x方向の辺長
+	 *	\param[in]	y	y方向の辺長
+	 *	\param[in]	z	z方向の辺長
+	 */
+	void	setSize(double x, double y, double z);
+
+	//! 個別辺長設定関数
+	/*!
+	 *	直方体の辺長を個別に設定します。
+	 *
+	 *	\param[in]	length	辺長
+	 *	\param[in]	axis	軸方向。以下のいずれかを指定します。
+	 *		- fk_X x方向
+	 *		- fk_Y y方向
+	 *		- fk_Z z方向
+	 */
+	void	setSize(double length, fk_Axis axis);
+
+	//! 全体拡大縮小関数
+	/*!
+	 *	直方体全体を、指定された倍率で拡大・縮小します。
+	 *
+	 *	\param[in]	scale	倍率
+	 */
+	void	setScale(double scale);
+
+	//! 軸方向拡大縮小関数
+	/*!
+	 *	直方体を、指定された軸方向についてのみ拡大・縮小します。
+	 *
+	 *	\param[in]	scale	倍率
+	 *	\param[in]	axis	軸方向。以下のいずれかを指定します。
+	 *		- fk_X x方向
+	 *		- fk_Y y方向
+	 *		- fk_Z z方向
+	 */
+	void	setScale(double scale, fk_Axis axis);
+
+	//! 軸方向個別拡大縮小関数
+	/*!
+	 *	直方体を、各軸方向に対し個別の倍率で拡大・縮小します。
+	 *
+	 *	\param[in]	x	x方向の倍率
+	 *	\param[in]	y	y方向の倍率
+	 *	\param[in]	z	z方向の倍率
+	 */
+	void	setScale(double x, double y, double z);
 };
 
 #endif // !__FK_BLOCK_HEADER__
