@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -78,22 +76,18 @@
 #include <FK/Vector.h>
 #include <list>
 
-class fk_LoopIndexAdmin {
-
- private:
-	int									maxID;
-	std::vector< std::vector<int> >		IDAdmin;
-
- public:
-	fk_LoopIndexAdmin(void);
-	~fk_LoopIndexAdmin();
-
-	void	PushRemoveID(int, int);
-	int		GetNewID(int);
-};
-
+//! 描画用キャッシュデータを管理するクラス
+/*!
+ *	このクラスは、 fk_Solid 型のデータを表示する際に
+ *	描画用データのキャッシングを制御するための機能を提供します。
+ *	通常、ユーザがこのクラスの機能を利用することはありません。
+ */
 class fk_DrawCache : public fk_DataAccess {
 
+	friend class	fk_PointDraw;
+	friend class	fk_LineDraw;
+	friend class	fk_FaceDraw;
+
  private:
 	std::list<fk_Vertex *>	vertexCache;
 	std::list<fk_Edge *>	edgeCache;
@@ -102,33 +96,6 @@ class fk_DrawCache : public fk_DataAccess {
 	std::vector<fk_Vector>	vertexArray;
 	std::vector<int>		ifsArray;
 
- protected:
-
-	fk_Vertex *			GetNewVertexObj(void);
-	fk_Vertex *			GetNewVertexObj(int);
-	fk_Half *			GetNewHalfObj(void);
-	fk_Half *			GetNewHalfObj(int);
-	fk_Edge *			GetNewEdgeObj(void);
-	fk_Edge *			GetNewEdgeObj(int);
-	fk_Loop *			GetNewLoopObj(void);
-	fk_Loop *			GetNewLoopObj(int);
-	fk_Shell *			GetNewShellObj(void);
-	fk_Shell *			GetNewShellObj(int);
-
-	bool				DeleteVertexObj(fk_Vertex *);
-	bool				DeleteVertexObj(int);
-	bool				DeleteHalfObj(fk_Half *);
-	bool				DeleteHalfObj(int);
-	bool				DeleteEdgeObj(fk_Edge *);
-	bool				DeleteEdgeObj(int);
-	bool				DeleteLoopObj(fk_Loop *);
-	bool				DeleteLoopObj(int);
-	bool				DeleteShellObj(fk_Shell *);
-	bool				DeleteShellObj(int);
-
- public:
-	fk_DrawCache(void);
-	~fk_DrawCache();
 
 	void			ClearVCache(void);
 	void			ClearECache(void);
@@ -151,11 +118,45 @@ class fk_DrawCache : public fk_DataAccess {
 	std::list<fk_Edge *> *		GetECache(void);
 	std::list<fk_Loop *> *		GetLCache(void);
 
-	void			AllCacheClear(void);
-	void			AllCacheMake(void);
-	void			allClear(void);
+ protected:
 
+#ifndef FK_DOXYGEN_USER_PROCESS
+
+	fk_Vertex *			GetNewVertexObj(void);
+	fk_Vertex *			GetNewVertexObj(int);
+	fk_Half *			GetNewHalfObj(void);
+	fk_Half *			GetNewHalfObj(int);
+	fk_Edge *			GetNewEdgeObj(void);
+	fk_Edge *			GetNewEdgeObj(int);
+	fk_Loop *			GetNewLoopObj(void);
+	fk_Loop *			GetNewLoopObj(int);
+
+	bool				DeleteVertexObj(fk_Vertex *);
+	bool				DeleteVertexObj(int);
+	bool				DeleteHalfObj(fk_Half *);
+	bool				DeleteHalfObj(int);
+	bool				DeleteEdgeObj(fk_Edge *);
+	bool				DeleteEdgeObj(int);
+	bool				DeleteLoopObj(fk_Loop *);
+	bool				DeleteLoopObj(int);
+
+	void				AllCacheClear(void);
+	void				AllCacheMake(void);
+
+#endif
+
+ public:
+
+#ifndef FK_DOXYGEN_USER_PROCESS
+
+	fk_DrawCache(void);
+	~fk_DrawCache();
+
+	void			AllClear_(void);
 	void			PrintCache(void);
+
+#endif
+
 };	
 
 
