@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -76,6 +74,28 @@
 
 #include <vector>
 
+//! 重複要素に同一IDを与えるための汎用テンプレート
+/*!
+ *	このテンプレートは、重複要素を管理する機能を提供します。
+ *	管理したいインスタンスを getID() 関数に代入したとき、
+ *	既に同じ値を持つインスタンスが代入済みであった場合にはその ID を返します。
+ *	初めて代入された値であった場合は、新しい ID を返します。
+ *	内部ではヒープソートを用いているため、
+ *	要素数が増加してもそれほど処理速度は低下しません。
+ *
+ *	対象となるクラスあるいは型においては、以下の条件を満たす必要があります。
+ *	- 等号演算子「==」によって値の同一性比較ができる。
+ *	- 不等号演算子「>」および「<」によって大小比較ができる。
+ *	- 不等号において、a < b かつ b < c であるならば a < c であるという
+ *		推移律が必ず成り立つ。逆方向も同様。
+ *	- getID() 関数を用いる際、これまでに格納した全インスタンスが生存している。
+ *	.
+ *	\remarks
+ *	本クラスは現在ベータ機能としての位置づけであり、
+ *	ユーザーズマニュアルには記載されていません。
+ *	また、今後のバージョンアップにおいて仕様が変更される可能性があります。
+ */
+
 template<class TYPE> class fk_HeapBase {
  private:
 	std::vector<TYPE *>		array;
@@ -158,15 +178,40 @@ template<class TYPE> class fk_HeapBase {
 			
  public:
 			
+	//! コンストラクタ
 	fk_HeapBase(void) { clear(); }
+
+	//! デストラクタ
 	~fk_HeapBase() { clear(); }
 
+	//! 初期化関数
+	/*!
+	 *	これまで格納した情報を全て初期化します。
+	 *	この関数を呼んだ場合、過去に格納したインスタンスは解放しても構いません。
+	 */
 	void clear(void);
 
+	/*!
+	 *	現時点での要素数を返します。
+	 *	これは、これまで返された ID の最大値でもあります。
+	 *	\return 要素数
+	 */
 	int getSize(void) {
 		return array.size();
 	}
 
+	/*!
+	 *	以下の条件で ID となる値を返します。
+	 *	- はじめて値を格納する場合、
+	 *		あるいは clear() を呼んではじめて値を格納する場合、
+	 *		ID として 1 を返します。
+	 *	- argV の値がこれまでに格納されたインスタンスの値と等しい場合、
+	 *		そのインスタンスの ID を返します。
+	 *	- argV がこれまでに格納されたどのインスタンスとも値が異なる場合、
+	 *	   	新しい ID を返します。
+	 *
+	 *	\param[in] argV	比較対象インスタンスのアドレス
+	 */
 	int getID(TYPE *argV) {
 		return HeapData(argV, 0, getSize()-1);
 	}
