@@ -164,6 +164,14 @@ class fk_IFSTexture : public fk_Texture {
 	 */
 	fk_IndexFaceSet *		getIFS(void);
 
+	//! 形状コピー関数
+	/*!
+	 *	引数として与えられたインスタンス中の形状やテクスチャデータをコピーします。
+	 *
+	 *	\param[in]		ifsTex	複写元インスタンス
+	 */
+	void				cloneShape(fk_IFSTexture *ifsTex);
+
 	//! テクスチャ座標設定関数
 	/*!
 	 *	テクスチャ座標を設定します。
