@@ -74,6 +74,7 @@
 
 #include <FK/ParserBase.H>
 #include <FK/ParserData.h>
+#include <list>
 
 class fk_D3DXAnimation;
 class fk_BVHMotion;
@@ -162,6 +163,10 @@ class fk_IndexFaceSet : public fk_ParserData {
 	int								faceSize;
 	fk_IFType						type;
 
+	bool							cloneFlg;
+	std::list<fk_IndexFaceSet *>	cloneList;
+	fk_IndexFaceSet					*orgIFS;
+
 	void				InitPNorm(void);
 	void				InitVNorm(void);
 	void				ModifyPNorm(void);
@@ -179,6 +184,8 @@ class fk_IndexFaceSet : public fk_ParserData {
 	bool				Init(int, int, int);
 	void				Init(void);
 
+	void				DeleteCloneLink(fk_IndexFaceSet *);
+
  public:
 
 	//! コンストラクタ
@@ -188,6 +195,15 @@ class fk_IndexFaceSet : public fk_ParserData {
 	~fk_IndexFaceSet();
 
 
+	//! 形状コピー関数
+	/*!
+	 *	引数として与えられたインスタンス中の形状をコピーします。
+	 *	各種属性およびマテリアル情報は写しません。
+	 *
+	 *	\param[in]		ifs		複写元インスタンス
+	 */
+	void				cloneShape(fk_IndexFaceSet *ifs);
+
 	//! \name ファイル・データ入力関数
 	//@(
 	//! SMFファイル入力関数
