@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -81,6 +79,25 @@ class fk_Model;
 
 const int FK_PICKDATAMAX	= 512;
 
+//! ピックによる取得データを管理するクラス
+/*!
+ *	このクラスは、ピックによって得られるデータを参照する機能を提供します。
+ *	「ピック」とは、マウスなどのポインティングデバイスによって画面上をクリックし、
+ *	形状要素を選択することです。具体的な利用方法については、
+ *	fk_Window::getPickModel(fk_PickData *, int),
+ *	fk_Window::getPickModel(fk_PickData *, int, int, int)
+ *	の解説を参照して下さい。ここでは、得られたデータの参照方法を主に記述します。
+ *
+ *	ピックデータは、以下の3種類によって構成されています。
+ *	- モデル
+ *	- 位相要素タイプ
+ *	- 位相要素 ID
+ *
+ *	\sa fk_Window::getPickModel(fk_PickData *, int),
+ *	fk_Window::getPickModel(fk_PickData *, int, int, int),
+ *	fk_Model::setPickMode()
+ */
+
 class fk_PickData : public fk_BaseObject {
  private:
 	std::vector<fk_Model *>		ModelArray;
@@ -88,18 +105,73 @@ class fk_PickData : public fk_BaseObject {
 	std::vector<fk_ObjectType>	typeArray;
 
  public:
+	//! コンストラクタ
 	fk_PickData(void);
+
+	//! デストラクタ
 	~fk_PickData();
+
+	//! コピーコンストラクタ
 	fk_PickData(const fk_PickData &);
+
+	//! 単純代入演算子
 	fk_PickData & operator =(const fk_PickData &);
 
+	//! 取得サイズ参照関数
+	/*!
+	 *	fk_Window::getPickModel() によって得られたデータの個数を返します。
+	 *
+	 *	\return		取得データ数
+	 */
+	int						getSize(void);
+
+	//! モデル参照関数
+	/*!
+	 *	得られたピックデータのモデルインスタンスのポインタを返します。
+	 *	
+	 *	\param[in]		index
+	 *		データのインデックス。
+	 *		最初の要素は 0 で、最後の要素は getSize() から 1 を引いた数となります。
+	 *
+	 *	\return		モデルインスタンスのポインタ
+	 */
+	fk_Model *				getModel(int index);
+
+	//! 位相タイプ参照関数
+	/*!
+	 *	得られたピックデータの位相タイプを返します。
+	 *	タイプは以下のいずれかとなります。
+	 *	- FK_VERTEX (頂点)
+	 *	- FK_EDGE	(稜線)
+	 *	- FK_LOOP	(面)
+	 *
+	 *	\param[in]		index
+	 *		データのインデックス。
+	 *		最初の要素は 0 で、最後の要素は getSize() から 1 を引いた数となります。
+	 *
+	 *	\return		位相タイプ
+	 */
+	fk_ObjectType			getType(int index);
+
+	//! 位相 ID 参照関数
+	/*!
+	 *	得られたピックデータの位相 ID を返します。
+	 *
+	 *	\param[in]		index
+	 *		データのインデックス。
+	 *		最初の要素は 0 で、最後の要素は getSize() から 1 を引いた数となります。
+	 *
+	 *	\return		位相ID
+	 */
+	int						getID(int index);
+
+#ifndef FK_DOXYGEN_USER_PROCESS
+
 	void					ClearData(void);
 	void					PushData(fk_Model *, int, fk_ObjectType);
 
-	int						getSize(void);
-	fk_Model *				getModel(int);
-	int						getID(int);
-	fk_ObjectType			getType(int);
+#endif
+
 };
 
 #endif // !__FK_PICKDATA_HEADER__
