@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -76,15 +74,69 @@
 
 #include <FK/IndexFace.h>
 
+//! 正多角柱・円柱を生成、管理するクラス
+/*!
+ *	このクラスは、形状として正多角柱や円柱を制御する機能を提供します。
+ *	円柱は、分割数の多い正多角柱として生成します。
+ *	通常、分割数が 20 を超える程度でほとんど円柱と見分けがつかなくなります。
+ *	配置は、底面の中心が原点となり、
+ *	多角柱の上面が -z 方向、底面が +z 方向となります。
+ *
+ *	設定できる要素は角数、上面半径、底面半径、高さの4要素です。
+ *	上面と底面の半径とは、それぞれの面を構成する正多角形の外接円半径を指します。
+ *
+ *	このクラスは、実質的には fk_IndexFaceSet クラスの派生クラスであり、
+ *	生成後に fk_IndexFaceSet クラスの機能によって頂点を移動することが可能です。
+ *	\sa fk_IndexFaceSet, fk_Shape, fk_Model, fk_Cone
+ */
+
 class fk_Prism: public fk_IndexFaceSet {
  public:
-	fk_Prism(int = 3, double = 1.0, double = 1.0, double = 1.0);
+
+	//! コンストラクタ
+	/*!
+	 *	\param[in]	div		角数
+	 *	\param[in]	top		上面半径
+	 *	\param[in]	bottom	底面半径
+	 *	\param[in]	height	高さ
+	 */
+	fk_Prism(int div = 3, double top = 1.0,
+			 double bottom = 1.0, double height = 1.0);
+
+	//! デストラクタ
 	~fk_Prism();
 
-	void	setDivide(int);
-	void	setTopRadius(double);
-	void	setBottomRadius(double);
-	void	setHeight(double);
+	//! 角数設定関数
+	/*!
+	 *	角数を変更します。
+	 *
+	 *	\param[in]	div	角数
+	 */		
+	void	setDivide(int div);
+
+	//! 上面半径設定関数
+	/*!
+	 *	上面半径を設定します。
+	 *
+	 *	\param[in]	rad	上面半径
+	 */
+	void	setTopRadius(double rad);
+
+	//! 底面半径設定関数
+	/*!
+	 *	底面半径を設定します。
+	 *
+	 *	\param[in]	rad	底面半径
+	 */
+	void	setBottomRadius(double rad);
+
+	//! 高さ設定関数
+	/*!
+	 *	高さを設定します。
+	 *
+	 *	\param[in]	height	高さ
+	 */
+	void	setHeight(double height);
 };
 
 #endif // !__FK_PRISM_HEADER__
