@@ -200,6 +200,16 @@ class fk_Solid : public fk_SolidBase {
 	 */
 	bool				readSMFFile(std::string fileName);
 
+	//! SRFファイル入力関数
+	/*!
+	 *	SRF形式のファイルからデータを入力します。
+	 *
+	 *	\param[in]	fileName	ファイル名
+	 *
+	 *	\return		成功すれば true を、失敗すれば false を返します。
+	 */
+	bool				readSRFFile(std::string fileName);
+
 	//! VRML ファイル入力関数
 	/*!
 	 *	VRML形式のファイルからデータを入力します。
