@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -76,13 +74,61 @@
 
 #include <FK/IndexFace.h>
 
+//! 球を生成、管理するクラス
+/*!
+ *	このクラスは、形状として球を制御する機能を提供しています。
+ *
+ *	実際には、球を近似する3角形面集合として表現されています。
+ *	3角形面の数は分割数を \f$ d \f$ とした場合 \f$ 8d(d-1) \f$ 枚となります。
+ *	分割数が高いほど球としての描画精度は高くなりますが、
+ *	面数も多くなるため描画速度が低下することになります。
+ *	特に多くのオブジェクトを同時に配置する場合は注意が必要です。
+ *
+ *	初期状態では、中心を原点とするように配置されます。
+ *	このクラスは fk_IndexFaceSet クラスの派生クラスであり、
+ *	生成後に fk_IndexFaceSet クラスの機能によって頂点を移動することが可能です。
+ *
+ *	\sa fk_IndexFaceSet, fk_Shape, fk_Model
+ */
+
 class fk_Sphere: public fk_IndexFaceSet {
  public:
-	fk_Sphere(int = 2, double = 1.0);
+
+	//! コンストラクタ
+	/*!
+	 *	引数として、分割数と半径を入力できます。分割数の最小値は 2 です。
+	 *
+	 *	\param[in]	div	分割数
+	 *	\param[in]	rad	半径
+	 */
+	fk_Sphere(int div = 2, double rad = 1.0);
+
+	//! デストラクタ
 	~fk_Sphere();
-	void	setDivide(int);
-	void	setRadius(double);
-	void	setScale(double);
+
+	//! 分割数設定関数
+	/*!
+	 *	分割数を設定します。分割数の最小値は 2 です。
+	 *
+	 *	\param[in]	div	分割数
+	 */
+	void	setDivide(int div);
+
+	//! 半径設定関数
+	/*!
+	 *	半径を設定します。
+	 *
+	 *	\param[in]	rad	半径
+	 */
+	void	setRadius(double rad);
+
+	//! 拡大縮小関数
+	/*!
+	 *	球全体を与えられた倍率で拡大縮小します。
+	 *
+	 *	\param[in]	scale	倍率
+	 */
+	void	setScale(double scale);
 };
 
 #endif // !__FK_SPHERE_HEADER__
