@@ -179,6 +179,8 @@ class fk_Texture: public fk_Shape {
 #ifndef FK_DOXYGEN_USER_PROCESS
 
 	void				BaseInit(void);
+	bool				IsLocalImage(void);
+	void				SetLocalImage(void);
 
 #endif
 
