@@ -488,6 +488,7 @@ class fk_UniStr : public fk_BaseObject {
 class fk_StrConverter {
  private:
 	ImdKanjiCodeConverter	*jisBase, *sjisBase, *eucBase;
+	ImdKanjiCodeConverter	*utf8_sjisBase, *sjis_utf8Base;
 	char					*buffer;
 	int						bufSize;
 
@@ -496,6 +497,8 @@ class fk_StrConverter {
 	void					InitJISBase(void);
 	void					InitSJISBase(void);
 	void					InitEUCBase(void);
+	void					InitUTF82SJISBase(void);
+	void					InitSJIS2UTF8Base(void);
 	void					CommonConvert(ImdKanjiCodeConverter *,
 										  const std::string &, fk_UniStr *);
 
@@ -531,6 +534,12 @@ class fk_StrConverter {
 	 *	\param[out]	uniStr	変換文字列を格納する fk_UniStr 型インスタンス
 	 */
 	void		convertEUC(const std::string &str, fk_UniStr *uniStr);
+
+#ifndef FK_DOXYGEN_USER_PROCESS
+	void		convertUTF8_SJIS(const std::string &, std::string *);
+	void		convertSJIS_UTF8(const std::string &, std::string *);
+#endif
+
 };
 
 #endif // !__FK_UNICODE_HEADER__
