@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -81,6 +79,19 @@
 class fk_Half;
 class fk_Loop;
 
+//! ソリッドモデルの頂点位相を管理するクラス
+/*!
+ *	このクラスは、 fk_Solid によるソリッドモデルにおいて、
+ *	頂点位相に関する制御機能を提供します。
+ *	FK におけるソリッドモデルの構造については、
+ *	ユーザーズマニュアルの「形状に対する高度な操作」の章を参照して下さい。
+ *
+ *	派生クラスのうち、ID 管理については fk_Topology,
+ *	個別マテリアル設定については fk_TopologyMaterial,
+ *	属性設定については fk_Attribute を参照して下さい。
+ *	\sa fk_Solid, fk_Half, fk_Edge, fk_Loop, fk_Topology, fk_TopologyMaterial, fk_Attribute
+ */
+
 class fk_Vertex : public fk_Topology, public fk_TopologyMaterial {
 
 	friend class		fk_Operation;
@@ -104,27 +115,74 @@ class fk_Vertex : public fk_Topology, public fk_TopologyMaterial {
 	void		SetNormal(const fk_Vector &);
 
  public:
+	//! コンストラクタ
 	fk_Vertex(int = FK_UNDEFINED);
+	//! デストラクタ
 	~fk_Vertex();
 
+	//! 初期化関数
+	/*!
+	 *	この関数は、頂点位相の初期化を行います。
+	 *	通常、ユーザがこの関数を利用することはありません。
+	 */
 	void		Init(int);
 
+	//! 位置ベクトル取得関数
+	/*!
+	 *	頂点位相の位置ベクトルを取得します。
+	 *	この関数による位置ベクトルは、
+	 *	fk_Model での配置や姿勢制御がまったく反映されないことに注意して下さい。
+	 *	\return 位置ベクトル
+	 */
 	fk_Vector	getPosition(void) const;
+
+	//! 接続半稜線取得関数
+	/*!
+	 *	この頂点を始点とする半稜線のうちの1つを取得します。
+	 *	条件を満たす全ての半稜線を得たい場合は、
+	 *	fk_ReferenceL2::getAllHOnV() 関数を用いて下さい。
+	 *	\return この頂点を始点とする半稜線を表す fk_Half 型インスタンスのアドレス。
+	 *	対象となる半稜線が存在しない場合は NULL を返します。
+	 */
 	fk_Half *	getOneHalf(void) const;
+
+	//! 法線ベクトル取得関数
+	/*!
+	 *	頂点が2次元多様体上にある条件下のもと、適切な法線ベクトルを取得します。
+	 *	\return 法線ベクトル。算出できなかった場合は零ベクトルを返します。
+	 */
 	fk_Vector	getNormal(void);
 
+	//! 描画サイズ取得関数
+	/*!
+	 *	頂点が描画される際のサイズを返します。
+	 *	\return 描画サイズ
+	 */
 	double		getDrawSize(void) const;
-	void		setDrawSize(double);
+
+	//! 描画サイズ設定関数
+	/*!
+	 *	頂点を描画する際のサイズを設定します。
+	 *	ここでの単位は「ピクセル」となります。
+	 *	カメラからの距離に関係なく、同一の大きさで描画されます。
+	 *	また、設定したサイズで実際に描画されるかどうかは
+	 *	グラフィックスハードウェアの機能に依存します。
+	 *	\param[in] size	描画サイズ
+	 */
+	void		setDrawSize(double size);
+
+#ifndef FK_DOXYGEN_USER_PROCESS
 
 	fk_Vector *	GetPositionP(void);
 	fk_Vector *	GetNormalP(void);
-
 	void		Print(void) const;
 	bool		Check(void) const;
 	bool		Compare(fk_Vertex *) const;
-
 	void		PutFile_Text(FILE *);
 	void		PutFile_Binary(FILE *);
+
+#endif
+
 };
 
 #endif // !__FK_VERTEX_HEADER__
