@@ -31,7 +31,7 @@
  *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
  *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
  *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- *	POSSIBILITY OF SUCH DAMAGE. 
+ *	POSSIBILITY OF SUCH DAMAGE.
  *
  ****************************************************************************/
 /****************************************************************************
@@ -82,7 +82,7 @@
 
 // for Graphics Header.
 #include <FL/Fl_Gl_Window.H>
-#include <FL/Fl_Multi_Browser.h>
+#include <FL/Fl_Multi_Browser.H>
 
 // for FK Header.
 #include <FK/Engine.H>
@@ -133,9 +133,9 @@ enum fk_SpecialKey {
 
 //! マウスボタンを表す列挙型
 enum fk_MouseButton {
-	FK_MOUSE1,		//!< マウス第1ボタン(左ボタン)
-	FK_MOUSE2,		//!< マウス第2ボタン(右ボタン)
-	FK_MOUSE3		//!< マウス第3ボタン(中ボタン、あるいはホイールボタン)
+	FK_MOUSE1,		//!< マウス左クリック(第1ボタン)
+	FK_MOUSE2,		//!< マウス中クリック、あるいはホイールクリック(第2ボタン)
+	FK_MOUSE3		//!< マウス右クリック(第3ボタン)
 };
 
 //! メッセージ出力タイプを表す列挙型
@@ -204,6 +204,8 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	unsigned long			frameInterval;
 	int						skipCount;
 
+	bool					stereoMode;
+
 	static Fl_Window		*putWin;
 	static Fl_Multi_Browser	*browser;
 	static fk_PutStrMode	putStrMode;
@@ -302,7 +304,7 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 *
 	 *	\code
 	 *	fk_Window		win;
-	 *	
+	 *
 	 *	if(win.getKeyStatus('a', true) == true) {
 	 *		// 押されている場合の処理
 	 *	}
@@ -338,7 +340,7 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 *
 	 *	\code
 	 *	fk_Window		win;
-	 *	
+	 *
 	 *	if(win.getSpecialKeyStatus(FK_RIGHT, true) == true) {
 	 *		// 押されている場合の処理
 	 *	}
@@ -429,7 +431,7 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 *
 	 *	\code
 	 *	fk_Window		win;
-	 *	
+	 *
 	 *	if(win.getMouseStatus(FK_MOUSE1, true) == true) {
 	 *		// 押されている場合の処理
 	 *	}
@@ -536,12 +538,12 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 *	その場合は、以下のようにビット論理和演算子を利用します。
 	 *	\code
 	 *	fk_Window	win;
-	 *	
+	 *
 	 *	win.setFrameMode(FK_WAIT_FRAME | FK_SKIP_FRAME);
 	 *	\endcode
 	 *
 	 *	\param[in]	mode		制御モード
-	 *	
+	 *
 	 *	\sa setFrameInterval(), getSkipFrame()
 	 */
 	void	setFrameMode(fk_FrameMode mode);
@@ -678,7 +680,7 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	 *		この関数による設定は、OpenGL 環境においてのみ有効です。
 	 *		Direct3D 版においては設定は意味をなしません。
 	 *
-	 *	\param[in]	mode	
+	 *	\param[in]	mode
 	 *		true の場合、頂点配列処理を有効とします。
 	 *		false の場合は無効とします。
 	 */
@@ -939,6 +941,44 @@ class fk_Window : public Fl_Gl_Window, public fk_BaseObject {
 	static void				clearBrowser(void);
 	//@)
 
+	//! \name 立体視モード制御関数
+	//@(
+	//! 立体視モード設定関数
+	/*!
+	 *	ウィンドウに対して立体視モードを設定します。
+	 *
+	 *	\note
+	 *		このシステムにおける立体視画像出力は、OpenGLの標準拡張機能を利用します。
+	 *		Direct3D版では利用できないので注意してください。
+	 *		立体視を利用するには、Quad Bufferをサポートしているグラフィックカードが必須です。
+	 *		本プロジェクトで動作を確認しているのはNVIDIA社のQuadroシリーズのみです。
+	 *		対応していない環境で立体視モードを有効にしようとした場合、
+	 *		その時点でプログラムは強制終了します。
+	 *		現時点ではプログラム的に立体視対応を判別する手段を用意していないので、
+	 *		使用する場合は立体視専用のアプリケーションとして構築してください。
+	 *
+	 *	\param[in]	mode
+	 *		trueだった場合、立体視モードを有効にします。
+	 *		falseだった場合、立体視モードを無効にします。
+	 *		いずれの動作においても、OpenGLの動作モードの再設定が行われます。
+	 *
+	 *	\sa fk_DisplayLink, getOGLStereoMode()
+	 */
+	void	setOGLStereoMode(bool mode);
+
+	//! 立体視モード取得関数
+	/*!
+	 *	ウィンドウの現在の立体視モードを取得します。
+	 *
+	 *	\return
+	 *		trueだった場合、立体視モードが有効になっています。
+	 *		falseだった場合、立体視モードが無効になっています。
+	 *
+	 *	\sa fk_DisplayLink, setOGLStereoMode()
+	 */
+	bool	getOGLStereoMode(void);
+	//@)
+
 #ifndef FK_DOXYGEN_USER_PROCESS
 
 	void	setOGLTextureBindMode(bool);
