@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,11 +73,11 @@
 
 fk_BaseObject::fk_BaseObject(fk_ObjectType argObjType)
 {
-	setObjectType(argObjType);
+	SetObjectType(argObjType);
 	return;
 }
 
-void fk_BaseObject::setObjectType(const fk_ObjectType argObjType)
+void fk_BaseObject::SetObjectType(const fk_ObjectType argObjType)
 {
 	ObjectType = argObjType;
 
