@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,12 +69,12 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/D3DXParser.h>
-#include <FK/D3DXData.h>
-#include <FK/D3DXAnimation.h>
-#include <FK/D3DXShapeParser.h>
+#include <FK/D3DXParser.H>
+#include <FK/D3DXData.H>
+#include <FK/D3DXAnimation.H>
+#include <FK/D3DXShapeParser.H>
 #include <FK/IFSTexture.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <FK/Tree.h>
 
 using namespace std;
@@ -99,22 +97,22 @@ fk_D3DXParser::~fk_D3DXParser()
 	return;
 }
 
-void fk_D3DXParser::setIFSTexture(fk_IFSTexture *argTexture)
+void fk_D3DXParser::SetIFSTexture(fk_IFSTexture *argTexture)
 {
 	ifsTexture = argTexture;
 	SetMeshData(argTexture->getIFS());
-	setAnimation(argTexture->getIFS()->getAnimation());
+	SetAnimation(argTexture->getIFS()->GetAnimation());
 	return;
 }
 
-void fk_D3DXParser::setAnimation(fk_D3DXAnimation *argAnim)
+void fk_D3DXParser::SetAnimation(fk_D3DXAnimation *argAnim)
 {
 	anim = argAnim;
 	anim->SetTree(tree);
 	return;
 }
 
-bool fk_D3DXParser::readD3DXFile(const string &argFileName,
+bool fk_D3DXParser::ReadD3DXFile(const string &argFileName,
 								 const string &argObjName,
 								 int argMateID,
 								 bool argSolidFlg)
@@ -397,7 +395,7 @@ bool fk_D3DXParser::MakeData(int argMateID, bool argSolidFlg)
 
 void fk_D3DXParser::print(void)
 {
-	tree->print();
+	tree->Print();
 	shape->Print();
 
 	return;
