@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/Base.h>
-#include <FK/DXFOut.h>
+#include <FK/DXFOut.H>
 #include <FK/Solid.h>
 #include <FK/IndexFace.h>
 #include <FK/Vertex.h>
@@ -101,7 +99,7 @@ fk_DXFOut::~fk_DXFOut()
 	return;
 }
 
-bool fk_DXFOut::writeDXFFile(string argFileName, bool argTriFlg)
+bool fk_DXFOut::WriteDXFFile(string argFileName, bool argTriFlg)
 {
 	FILE		*writeFP;
 	bool		retFlg;
