@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,13 +70,12 @@
  *
  ****************************************************************************/
 #include <FK/DataAccess.h>
-#include <FK/DataBase.h>
+#include <FK/DataBase.H>
 #include <FK/Vertex.h>
 #include <FK/Half.h>
 #include <FK/Edge.h>
 #include <FK/Loop.h>
-#include <FK/Shell.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 fk_DataAccess::fk_DataAccess(void)
 {
@@ -168,18 +165,6 @@ fk_Loop * fk_DataAccess::GetNewLoopObj_(int argID)
 	return ope_DB->GetNewLoop(argID);
 }
 
-fk_Shell * fk_DataAccess::GetNewShellObj_(void)
-{
-	if(checkDB() == false) return (fk_Shell *)NULL;
-	return ope_DB->GetNewShell();
-}
-
-fk_Shell * fk_DataAccess::GetNewShellObj_(int argID)
-{
-	if(checkDB() == false) return (fk_Shell *)NULL;
-	return ope_DB->GetNewShell(argID);
-}
-
 bool fk_DataAccess::DeleteVertexObj_(fk_Vertex *argV)
 {
 	if(checkDB() == false) return false;
@@ -204,12 +189,6 @@ bool fk_DataAccess::DeleteLoopObj_(fk_Loop *argL)
 	return ope_DB->DeleteLoop(argL->getID());
 }
 
-bool fk_DataAccess::DeleteShellObj_(fk_Shell *argS)
-{
-	if(checkDB() == false) return false;
-	return ope_DB->DeleteShell(argS->getID());
-}
-
 void fk_DataAccess::AllDBClear_(void)
 {
 	if(checkDB() == true) {
@@ -266,18 +245,6 @@ bool fk_DataAccess::existLoop(int argID) const
 	return ope_DB->ExistLoop(argID);
 }
 
-bool fk_DataAccess::existShell(fk_Shell *argS) const
-{
-	if(checkDB() == false) return false;
-	return ope_DB->ExistShell(argS);
-}
-
-bool fk_DataAccess::existShell(int argID) const
-{
-	if(checkDB() == false) return false;
-	return ope_DB->ExistShell(argID);
-}
-
 fk_Vertex * fk_DataAccess::getVData(int argID) const
 {
 	if(checkDB() == false) return (fk_Vertex *)NULL;
@@ -302,12 +269,6 @@ fk_Loop * fk_DataAccess::getLData(int argID) const
 	return ope_DB->GetLData(argID);
 }
 
-fk_Shell * fk_DataAccess::getSData(int argID) const
-{
-	if(checkDB() == false) return (fk_Shell *)NULL;
-	return ope_DB->GetSData(argID);
-}
-
 fk_Vertex * fk_DataAccess::getNextV(fk_Vertex *argV) const
 {
 	if(checkDB() == false) return (fk_Vertex *)NULL;
@@ -332,12 +293,6 @@ fk_Loop * fk_DataAccess::getNextL(fk_Loop *argL) const
 	return ope_DB->GetNextL(argL);
 }
 
-fk_Shell * fk_DataAccess::getNextS(fk_Shell *argS) const
-{
-	if(checkDB() == false) return (fk_Shell *)NULL;
-	return ope_DB->GetNextS(argS);
-}
-
 fk_Vertex * fk_DataAccess::getLastV(void) const
 {
 	if(checkDB() == false) return (fk_Vertex *)NULL;
@@ -362,12 +317,6 @@ fk_Loop * fk_DataAccess::getLastL(void) const
 	return ope_DB->GetLastL();
 }
 
-fk_Shell * fk_DataAccess::getLastS(void) const
-{
-	if(checkDB() == false) return (fk_Shell *)NULL;
-	return ope_DB->GetLastS();
-}
-
 int fk_DataAccess::getVNum(void) const
 {
 	if(checkDB() == false) return -1;
@@ -391,9 +340,3 @@ int fk_DataAccess::getLNum(void) const
 	if(checkDB() == false) return -1;
 	return ope_DB->GetLNum();
 }
-
-int fk_DataAccess::getSNum(void) const
-{
-	if(checkDB() == false) return -1;
-	return ope_DB->GetSNum();
-}
