@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,21 +70,20 @@
  *
  ****************************************************************************/
 #include <FK/Base.h>
-#include <FK/DataBase.h>
+#include <FK/DataBase.H>
 
 #ifdef FK_EXTERN
 #undef FK_EXTERN
 #endif
 #define FK_EXTERN extern
 
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 #include <FK/Vertex.h>
 #include <FK/Half.h>
 #include <FK/Edge.h>
 #include <FK/Loop.h>
-#include <FK/Shell.h>
-#include <FK/ParserBase.h>
+#include <FK/ParserBase.H>
 
 using namespace std;
 
@@ -106,7 +103,6 @@ void fk_DataBase::AllClear(void)
 	hAdmin.Init(1);
 	eAdmin.Init(1);
 	lAdmin.Init(1);
-	sAdmin.Init(1);
 
 	while(!vSet.empty()) {
 		delete vSet.back();
@@ -128,11 +124,6 @@ void fk_DataBase::AllClear(void)
 		lSet.pop_back();
 	}
 
-	while(!sSet.empty()) {
-		delete sSet.back();
-		sSet.pop_back();
-	}
-
 	return;
 }
 
@@ -144,7 +135,6 @@ void fk_DataBase::CloneData(fk_DataBase *argDB)
 	hAdmin.CloneData(&argDB->hAdmin);
 	eAdmin.CloneData(&argDB->eAdmin);
 	lAdmin.CloneData(&argDB->lAdmin);
-	sAdmin.CloneData(&argDB->sAdmin);
 
 	ResizeData(argDB);
 
@@ -152,7 +142,6 @@ void fk_DataBase::CloneData(fk_DataBase *argDB)
 	HSetClone(&argDB->hSet);
 	ESetClone(&argDB->eSet);
 	LSetClone(&argDB->lSet);
-	SSetClone(&argDB->sSet);
 
 	return;
 }
@@ -311,31 +300,12 @@ void fk_DataBase::LSetClone(vector<fk_Loop *> *argLSet)
 	return;
 }
 
-void fk_DataBase::SSetClone(vector<fk_Shell *> *argSSet)
-{
-	unsigned int	i;
-	fk_Shell		*orgS, *newS;
-
-	for(i = 0; i < sSet.size(); i++) {
-		orgS = (*argSSet)[i];
-		newS = sSet[i];
-
-		if(newS->CloneElem(orgS) == false) {
-			continue;
-		}
-
-		newS->oneLoop = GetLData(orgS->oneLoop->getID());
-	}
-	return;
-}
-
 bool fk_DataBase::Compare(fk_DataBase *argDB)
 {
 	if(VCompare(argDB) == true &&
 	   HCompare(argDB) == true &&
 	   ECompare(argDB) == true &&
-	   LCompare(argDB) == true &&
-	   SCompare(argDB) == true) {
+	   LCompare(argDB) == true) {
 		return true;
 	}
 
@@ -411,23 +381,6 @@ bool fk_DataBase::LCompare(fk_DataBase *argDB)
 	return true;
 }
 
-bool fk_DataBase::SCompare(fk_DataBase *argDB)
-{
-	fk_Shell	*s1, *s2;
-
-	s1 = GetNextS((fk_Shell *)NULL);
-	s2 = argDB->GetNextS((fk_Shell *)NULL);
-
-	while(s1 != (fk_Shell *)NULL) {
-		if(s1->Compare(s2) == false) return false;
-		s1 = GetNextS(s1);
-		s2 = argDB->GetNextS(s2);
-	}
-
-	if(s2 != (fk_Shell *)NULL) return false;
-	return true;
-}
-
 fk_Vertex * fk_DataBase::GetNewVertex(void)
 {
 	int newID = vAdmin.CreateID();
@@ -539,34 +492,6 @@ fk_Loop * fk_DataBase::GetNewLoop(int argID)
 	return lSet[argID-1];
 }
 
-fk_Shell * fk_DataBase::GetNewShell(void)
-{
-	int	newID = sAdmin.CreateID();
-
-	if((int)sSet.size() == newID - 1) {
-		sSet.push_back(new fk_Shell(newID));
-	} else {
-		sSet[newID-1]->MakeElem(newID);
-	}
-
-	return sSet[newID-1];
-}
-
-fk_Shell * fk_DataBase::GetNewShell(int argID)
-{
-	if(sAdmin.CreateID(argID) == false) {
-		return (fk_Shell *)NULL;
-	}
-
-	if((int)sSet.size() == argID - 1) {
-		sSet.push_back(new fk_Shell(argID));
-	} else {
-		sSet[argID-1]->MakeElem(argID);
-	}
-
-	return sSet[argID-1];
-}
-
 bool fk_DataBase::ExistVertex(fk_Vertex *argVx) const
 {
 	if(argVx == (fk_Vertex *)NULL) return false;
@@ -619,19 +544,6 @@ bool fk_DataBase::ExistLoop(int argID) const
 	return lAdmin.ExistID(argID);
 }
 
-bool fk_DataBase::ExistShell(fk_Shell *argS) const
-{
-	if(argS == (fk_Shell *)NULL) return false;
-	if(ExistShell(argS->getID()) == false) return false;
-	if(sSet[argS->getID() - 1] != argS) return false;
-	return true;
-}
-
-bool fk_DataBase::ExistShell(int argID) const
-{
-	return sAdmin.ExistID(argID);
-}
-
 bool fk_DataBase::DeleteVertex(int argID)
 {
 	if(vAdmin.EraseID(argID) == false) return false;
@@ -660,13 +572,6 @@ bool fk_DataBase::DeleteLoop(int argID)
 	return true;
 }
 
-bool fk_DataBase::DeleteShell(int argID)
-{
-	if(sAdmin.EraseID(argID) == false) return false;
-	sSet[argID-1]->DeleteElem();
-	return true;
-}
-
 fk_Vertex * fk_DataBase::GetVData(int argVID) const
 {
 	if(vAdmin.ExistID(argVID) == false) return (fk_Vertex *)NULL;
@@ -691,12 +596,6 @@ fk_Loop * fk_DataBase::GetLData(int argLID) const
 	return lSet[argLID - 1];
 }
 
-fk_Shell * fk_DataBase::GetSData(int argSID) const
-{
-	if(sAdmin.ExistID(argSID) == false) return (fk_Shell *)NULL;
-	return sSet[argSID - 1];
-}
-
 fk_Vertex * fk_DataBase::GetNextV(fk_Vertex *argV) const
 {
 	if(argV == (fk_Vertex *)NULL) {
@@ -733,15 +632,6 @@ fk_Loop * fk_DataBase::GetNextL(fk_Loop *argL) const
 	}
 }
 
-fk_Shell * fk_DataBase::GetNextS(fk_Shell *argS) const
-{
-	if(argS == (fk_Shell *)NULL) {
-		return GetSData(sAdmin.GetNext(0));
-	} else {
-		return GetSData(sAdmin.GetNext(argS->getID()));
-	}
-}
-
 fk_Vertex * fk_DataBase::GetLastV(void) const
 {
 	return GetVData(vAdmin.GetMaxID());
@@ -762,11 +652,6 @@ fk_Loop * fk_DataBase::GetLastL(void) const
 	return GetLData(lAdmin.GetMaxID());
 }
 
-fk_Shell * fk_DataBase::GetLastS(void) const
-{
-	return GetSData(sAdmin.GetMaxID());
-}
-
 int fk_DataBase::GetVNum(void) const
 {
 	return vAdmin.GetIDNum();
@@ -787,11 +672,6 @@ int fk_DataBase::GetLNum(void) const
 	return lAdmin.GetIDNum();
 }
 
-int fk_DataBase::GetSNum(void) const
-{
-	return sAdmin.GetIDNum();
-}
-
 void fk_DataBase::VPrint(int argID) const
 {
 	register unsigned int	i;
@@ -865,31 +745,12 @@ void fk_DataBase::LPrint(int argID) const
 	return;
 }
 
-void fk_DataBase::SPrint(int argID) const
-{
-	register unsigned int	i;
-
-	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < sSet.size(); i++) {
-			if(sSet[i]->getID() != FK_UNDEFINED) sSet[i]->Print();
-		}
-	} else if(!sAdmin.ExistID(argID)) {
-		fk_PutError("fk_DataBase", "SPrint", 1,
-					"Shell Admin Error.");
-	} else {
-		sSet[argID-1]->Print();
-	}
-
-	return;
-}
-
 void	fk_DataBase::AllPrint(void) const
 {
 	VPrint(FK_UNDEFINED);
 	HPrint(FK_UNDEFINED);
 	EPrint(FK_UNDEFINED);
 	LPrint(FK_UNDEFINED);
-	SPrint(FK_UNDEFINED);
 
 	return;
 }
@@ -990,30 +851,6 @@ bool fk_DataBase::LCheck(int argID) const
 	return retBool;
 }
 
-bool fk_DataBase::SCheck(int argID) const
-{
-	register unsigned int	i;
-	bool					retBool = true;
-
-	if(argID == FK_UNDEFINED) {
-		for(i = 0; i < sSet.size(); i++) {
-			if(sSet[i]->getID() != FK_UNDEFINED) {
-				if(sSet[i]->Check() == false) {
-					retBool = false;
-				}
-			}
-		}
-	} else if(!sAdmin.ExistID(argID)) {
-		fk_PutError("fk_DataBase", "SCheck", 1,
-					"Shell Admin Error");
-		retBool = false;
-	} else {
-		retBool = sSet[argID-1]->Check();
-	}
-
-	return retBool;
-}
-
 bool fk_DataBase::AllCheck(void) const
 {
 	bool	retBool = true;
@@ -1022,7 +859,6 @@ bool fk_DataBase::AllCheck(void) const
 	if(HCheck() == false) retBool = false;
 	if(ECheck() == false) retBool = false;
 	if(LCheck() == false) retBool = false;
-	if(SCheck() == false) retBool = false;
 
 	return retBool;
 }
