@@ -269,6 +269,7 @@ void fk_GraphicsEngine::OpenGLInit(void)
 	glEnable(GL_POLYGON_OFFSET_FILL);
 	glPolygonOffset(1.0f, 1.0f);
 	glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
+	glPixelStorei(GL_PACK_ALIGNMENT, 1);
 	glPolygonMode(GL_FRONT, GL_FILL);
 	glDisable(GL_BLEND);
 	glAlphaFunc(GL_GREATER, 0.01f);
@@ -284,7 +285,83 @@ void fk_GraphicsEngine::OpenGLInit(void)
 	return;
 }
 
-void fk_GraphicsEngine::Draw(bool argPickFlg)
+void fk_GraphicsEngine::SetStereoViewPort(int channel)
+{
+	glViewport(0, 0, wSize, hSize);
+	glMatrixMode(GL_PROJECTION);
+	glLoadIdentity();
+
+	if(curDLink == (fk_DisplayLink *)NULL) {
+		SetDefaultProjection();
+	} else {
+		SetProjection(curDLink->getStereoProjection((fk_StereoChannel)channel));
+	}
+
+	glMatrixMode(GL_MODELVIEW);
+	glLoadIdentity();
+	gluLookAt(0.0, 0.0, 0.0, 0.0, 0.0, -1.0, 0.0, 1.0, 0.0);
+
+	return;
+}
+
+void fk_GraphicsEngine::RecalcStereoModelView(int channel)
+{
+	if(curDLink != NULL) {
+		const fk_Model	*camera = curDLink->getStereoCamera((fk_StereoChannel)channel);
+		if(camera == NULL) {
+			RecalcInhModelView(curDLink->getCamera());
+		} else {
+			RecalcInhModelView(camera);
+		}
+	}
+
+	return;
+}
+
+void fk_GraphicsEngine::StereoDraw(void)
+{
+	//bool			fogStatus = false;
+	fk_Scene		*scene;
+	fk_Color		bgColor;
+
+	scene = NULL;
+
+	// どうせ毎回ビューポートを設定するのでリサイズフラグは潰す
+	if(resizeFlag == true || generalID > 2) {
+		//SetViewPort();
+		resizeFlag = false;
+	}
+
+	ApplySceneParameter(false);
+
+	// Left eye
+	glDrawBuffer(GL_BACK_LEFT);
+	glClear(static_cast<GLbitfield>(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT));
+
+	SetStereoViewPort(FK_STEREO_LEFT);
+	glPushMatrix();
+
+	RecalcStereoModelView(FK_STEREO_LEFT);
+	DrawObjs(false);
+	glPopMatrix();
+	glFlush();
+
+	// Right eye
+	glDrawBuffer(GL_BACK_RIGHT);
+	glClear(static_cast<GLbitfield>(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT));
+
+	SetStereoViewPort(FK_STEREO_RIGHT);
+	glPushMatrix();
+
+	RecalcStereoModelView(FK_STEREO_RIGHT);
+	DrawObjs(false);
+	glPopMatrix();
+	glFlush();
+
+	return;
+}
+
+void fk_GraphicsEngine::ApplySceneParameter(bool argVPFlg)
 {
 	bool			fogStatus = false;
 	fk_Scene		*scene;
@@ -292,18 +369,14 @@ void fk_GraphicsEngine::Draw(bool argPickFlg)
 
 	scene = NULL;
 
-	// リサイズ時に加えて、マルチウィンドウ時もビューポートを再設定(by rita)
-	if(resizeFlag == true || generalID > 2) {
-		SetViewPort();
-		resizeFlag = false;
-	}
-
 	if(curDLink != NULL) {
 		if(dLinkID != curDLink->GetID() ||
 		   dLinkStatus != curDLink->GetProjChangeStatus()) {
 			dLinkID = curDLink->GetID();
 			dLinkStatus = curDLink->GetProjChangeStatus();
-			SetViewPort();
+			if(argVPFlg == true) {
+				SetViewPort();
+			}
 			if(curDLink->getObjectType() == FK_SCENE) {
 				scene = static_cast<fk_Scene *>(curDLink);
 				scene->GetFogChangeStatus();
@@ -334,6 +407,25 @@ void fk_GraphicsEngine::Draw(bool argPickFlg)
 		glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
 	}
 
+	return;
+}
+
+void fk_GraphicsEngine::Draw(bool argPickFlg)
+{
+	//bool			fogStatus = false;
+	fk_Scene		*scene;
+	fk_Color		bgColor;
+
+	scene = NULL;
+
+	// リサイズ時に加えて、マルチウィンドウ時もビューポートを再設定(by rita)
+	if(resizeFlag == true || generalID > 2) {
+		SetViewPort();
+		resizeFlag = false;
+	}
+
+	ApplySceneParameter(true);
+
 	glClear(static_cast<GLbitfield>(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT));
 
 	glPushMatrix();
@@ -442,8 +534,11 @@ void fk_GraphicsEngine::DrawModel(fk_Model *argModel,
 	  case FK_TRITEXTURE:
 	  case FK_MESHTEXTURE:
 	  case FK_IFSTEXTURE:
+		if(textureMode == false) {
+			glEnable(GL_TEXTURE_2D);
+			textureMode = true;
+		}
 		textureDraw->DrawTextureObj(argModel, argLightFlg, argPickFlg);
-		textureMode = true;
 		break;
 
 	  default:
