@@ -133,7 +133,7 @@ HRESULT fk_GraphicsEngine::InitD3D(HWND hWnd, bool argErrRep)
 	// 現在の画面モードを使用
 	m_d3dpp.BackBufferFormat = d3ddm.Format;
 	m_d3dpp.MultiSampleType = D3DMULTISAMPLE_NONE;
-	m_d3dpp.SwapEffect = D3DSWAPEFFECT_DISCARD;
+	m_d3dpp.SwapEffect = D3DSWAPEFFECT_FLIP;
 	m_d3dpp.hDeviceWindow = m_hWnd;
 	// Z バッファの自動作成
 	m_d3dpp.EnableAutoDepthStencil = TRUE;
@@ -1153,50 +1153,28 @@ bool fk_GraphicsEngine::SnapImage(string argFName, fk_ImageType argType, fk_Snap
 
 bool fk_GraphicsEngine::SnapImage(fk_Image *argImage, fk_SnapProcMode argMode)
 {
-	int					wCount, hCount;
-	LPDIRECT3DSURFACE9	pSurface;
-	D3DLOCKED_RECT		snapRect;
-	RECT				winRect;
-	unsigned char		*ref_buffer;
+	LPDIRECT3DSURFACE9	pSurface = NULL;
+	LPD3DXBUFFER		pBuffer = NULL;
 
 	if(argImage == (fk_Image *)NULL) return false;
 
-	// 現在の画面モードを取得
-    D3DDISPLAYMODE d3ddm;
-    if(FAILED(g_lpD3D->GetAdapterDisplayMode(D3DADAPTER_DEFAULT, &d3ddm))) return false;
-
-	// サーフェスを生成
-	ref_lpD3DDEV->CreateOffscreenPlainSurface(d3ddm.Width, d3ddm.Height, D3DFMT_A8R8G8B8, D3DPOOL_SCRATCH, &pSurface, NULL);
-	// フロントバッファのデータをコピー
-	if(D3D_OK != m_lpD3DSC->GetFrontBufferData(pSurface)) {
-		pSurface->Release();
+	// バックバッファを取得
+	if(D3D_OK != m_lpD3DSC->GetBackBuffer(0, D3DBACKBUFFER_TYPE_MONO, &pSurface)) {
 		return false;
 	}
-	// ロックして読み出し準備
-	if(D3D_OK != pSurface->LockRect(&snapRect, NULL, D3DLOCK_READONLY)) {
-		pSurface->Release();
+
+	// オンメモリBMPファイルとして書き出し
+	if(D3D_OK != D3DXSaveSurfaceToFileInMemory(&pBuffer, D3DXIFF_BMP, pSurface, NULL, NULL)) {
 		return false;
 	}
-	ref_buffer = (unsigned char*)snapRect.pBits;
 
-	GetWindowRect(m_hWnd, &winRect);
-
-	if(argImage->getWidth() != wSize || argImage->getHeight() != hSize) {
-		argImage->newImage(wSize, hSize);
+	// オンメモリBMPからfk_Imageへ取り込み
+	if(!argImage->readBMPData((fk_ImType *)pBuffer->GetBufferPointer())) {
+		pBuffer->Release();
+		return false;
 	}
 
-    for(hCount = 0; hCount < hSize; hCount++) {
-		for(wCount = 0; wCount < wSize; wCount++) {
-			argImage->setRGB(wCount, hCount,
-				ref_buffer[4*((hCount+winRect.top)*d3ddm.Width + (wCount+winRect.left))+2],
-				ref_buffer[4*((hCount+winRect.top)*d3ddm.Width + (wCount+winRect.left))+1],
-				ref_buffer[4*((hCount+winRect.top)*d3ddm.Width + (wCount+winRect.left))]);
-		}
-	}
-
-	pSurface->UnlockRect();
-	pSurface->Release();
-
+	pBuffer->Release();
 	return true;
 }
 
