@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -412,7 +410,7 @@ int fk_FaceDraw::DrawSolidFaceMaterialElem(fk_Model *argObj, fk_Loop *argL,
 {
 	fk_Half					*startH, *curH;
 	fk_Vertex				*curV;
-	fk_Vector				*tmpPosP, *tmpNormP;
+	fk_Vector				*tmpNormP;
 	int						retMateID, curMateID;
 	fk_Surface				*surf;
 	unsigned int			i;
@@ -842,7 +840,7 @@ void fk_FaceDraw::DrawSolidFaceNormalElem(fk_Loop *argL)
 {
 	fk_Half				*startH, *curH;
 	fk_Vertex			*curV;
-	fk_Vector			*tmpPosP, *tmpNormP;
+	fk_Vector			*tmpNormP;
 	unsigned int		i;
 	vector<fk_Vertex *>	*tesseVertexArray;
 	vector<int>			*tesseIDArray;
