@@ -762,12 +762,9 @@ bool fk_FileInput::GetMainMaterialData(fk_DataFormatMode argMode, FILE *argFP)
 	char					buffer[512], tag[256];
 	string					tagStr;
 	int						valSet[2];
-	vector<fk_Material>		*palStack;
 	fk_Material				localMat;
 
 
-	palStack = palette->getMaterialVector();
-
 	switch(argMode) {
 	  case FK_TEXT_FILE:
 		fgets(buffer, 511, argFP);
@@ -787,7 +784,7 @@ bool fk_FileInput::GetMainMaterialData(fk_DataFormatMode argMode, FILE *argFP)
 	}
 
 	palette->setObjMaterialID(valSet[0]);
-	palStack->resize(valSet[1]);
+	palette->Resize(valSet[1]);
 
 	if(GetMaterialData(argMode, argFP, &localMat) == false) {
 		return false;
