@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,14 +69,13 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/FileOutput.h>
-#include <FK/DataBase.h>
+#include <FK/FileOutput.H>
+#include <FK/DataBase.H>
 #include <FK/Palette.h>
 #include <FK/Vertex.h>
 #include <FK/Half.h>
 #include <FK/Edge.h>
 #include <FK/Loop.h>
-#include <FK/Shell.h>
 
 using namespace std;
 
@@ -199,7 +196,7 @@ void fk_FileOutput::PutHeader(fk_DataFormatMode argMode, FILE *argFP)
 		buffer[2] = FK_FILE_CURRENT_MINOR_VERSION;
 		buffer[3] = FK_FILE_CURRENT_SUBMINOR_VERSION;
 		
-		bWrite(buffer, 4, argFP);
+		BWrite(buffer, 4, argFP);
 		return;
 
 	  default:
@@ -232,7 +229,7 @@ bool fk_FileOutput::PutShapeData_(fk_DataFormatMode argMode, FILE *argFP)
 
 	  case FK_BINARY_FILE:
 
-		bWrite(setSize, 5, argFP);
+		BWrite(setSize, 5, argFP);
 		break;
 
 	  default:
@@ -303,10 +300,10 @@ void fk_FileOutput::PutVertexData(fk_DataFormatMode argMode,
 		
 	  case FK_BINARY_FILE:
 		
-		bWrite(IDSet, 3, argFP);
-		bWrite(pos, 3, argFP);
+		BWrite(IDSet, 3, argFP);
+		BWrite(pos, 3, argFP);
 		if(sizeMode == true) {
-			bWrite(&size, 1, argFP);
+			BWrite(&size, 1, argFP);
 		}
 		
 		break;
@@ -357,7 +354,7 @@ void fk_FileOutput::PutHalfData(fk_DataFormatMode argMode,
 		
 	  case FK_BINARY_FILE:		
 		
-		bWrite(IDSet, 4, argFP);
+		BWrite(IDSet, 4, argFP);
 		break;
 		
 	  default:
@@ -395,9 +392,9 @@ void fk_FileOutput::PutEdgeData(fk_DataFormatMode argMode,
 		
 	  case FK_BINARY_FILE:
 		
-		bWrite(IDSet, 4, argFP);
+		BWrite(IDSet, 4, argFP);
 		if(sizeMode == true) {
-			bWrite(&width, 1, argFP);
+			BWrite(&width, 1, argFP);
 		}
 		break;
 		
@@ -432,7 +429,7 @@ void fk_FileOutput::PutLoopData(fk_DataFormatMode argMode,
 		
 	  case FK_BINARY_FILE:
 		
-		bWrite(IDSet, 3, argFP);
+		BWrite(IDSet, 3, argFP);
 		break;
 		
 	  default:
@@ -488,7 +485,7 @@ void fk_FileOutput::PutAdminHeader(fk_DataFormatMode argMode,
 		
 	  case FK_BINARY_FILE:
 		
-		bWrite(sizeSet, 2, argFP);
+		BWrite(sizeSet, 2, argFP);
 		break;
 		
 	  default:
@@ -512,7 +509,7 @@ void fk_FileOutput::PutAdminEraseList(fk_DataFormatMode argMode, FILE *argFP,
 		
 	  case FK_BINARY_FILE:
 		if(argSize != 0) {
-			bWrite(argArray, argSize, argFP);
+			BWrite(argArray, argSize, argFP);
 		}
 		break;
 		
@@ -528,6 +525,8 @@ bool fk_FileOutput::PutPaletteData_(fk_DataFormatMode argMode, FILE *argFP)
 	unsigned int			i;
 	vector<fk_Material>		*matVec;
 	int						valueSet[2];
+	fk_Material				dummyMat;
+
 
 	matVec = palette->getMaterialVector();
 
@@ -536,10 +535,16 @@ bool fk_FileOutput::PutPaletteData_(fk_DataFormatMode argMode, FILE *argFP)
 		fprintf(argFP, "mat\t%d\t%d\n",
 				palette->getObjMaterialID(), int(matVec->size()));
 
+		/*
 		if(PutMaterialData(FK_TEXT_FILE, argFP,
 						   palette->getObjMaterial()) == false) {
 			return false;
 		}
+		*/
+
+		if(PutMaterialData(FK_TEXT_FILE, argFP, &dummyMat) == false) {
+			return false;
+		}
 
 		for(i = 0; i < matVec->size(); i++) {
 			if(PutMaterialData(FK_TEXT_FILE, argFP,
@@ -554,12 +559,18 @@ bool fk_FileOutput::PutPaletteData_(fk_DataFormatMode argMode, FILE *argFP)
 		valueSet[0] = palette->getObjMaterialID();
 		valueSet[1] = matVec->size();
 
-		bWrite(valueSet, 2, argFP);
+		BWrite(valueSet, 2, argFP);
 
+		/*
 		if(PutMaterialData(FK_BINARY_FILE, argFP,
 						   palette->getObjMaterial()) == false) {
 			return false;
 		}
+		*/
+
+		if(PutMaterialData(FK_BINARY_FILE, argFP, &dummyMat) == false) {
+			return false;
+		}
 
 		for(i = 0; i < matVec->size(); i++) {
 			if(PutMaterialData(FK_BINARY_FILE, argFP,
@@ -610,7 +621,7 @@ bool fk_FileOutput::PutMaterialData(fk_DataFormatMode argMode, FILE *argFP,
 
 	  case FK_BINARY_FILE:
 		value = argMat->getAlpha();
-		if(bWrite(&value, 1, argFP) != 1) return false;
+		if(BWrite(&value, 1, argFP) != 1) return false;
 
 		for(int i = 0; i < 3; i++) {
 			colArray[i] = argMat->getAmbient()->col[i];
@@ -619,10 +630,10 @@ bool fk_FileOutput::PutMaterialData(fk_DataFormatMode argMode, FILE *argFP,
 			colArray[i+9] = argMat->getEmission()->col[i];
 		}
 		
-		if(bWrite(colArray, 12, argFP) == false) return false;
+		if(BWrite(colArray, 12, argFP) == false) return false;
 		
 		value = argMat->getShininess();
-		if(bWrite(&value, 1, argFP) != 1) return false;
+		if(BWrite(&value, 1, argFP) != 1) return false;
 
 		break;
 
