@@ -342,7 +342,7 @@ fk_ImageStatus fk_Image::SaveBmpFile(string argFName, bool argTransFlg)
 	vector<fk_ImType>	bmpFileHeader;
 	vector<fk_ImType>	bmpInfoHeader;
 	vector<fk_ImType>	bmpBuffer;
-	int					bmpBufSize, y;
+	int					bmpBufSize, x, y;
 	int					bitSize;
 
 	if(imageBuf.empty() == true) return FK_IMAGE_DATAERROR;
@@ -366,13 +366,14 @@ fk_ImageStatus fk_Image::SaveBmpFile(string argFName, bool argTransFlg)
 	}
 
 	bmpBuffer.resize(bmpBufSize);
+	for(x = 0; x < bmpBufSize; x++) bmpBuffer[x] = 0;
 
 	fwrite(&bmpFileHeader[0], sizeof(fk_ImType), bmpFileHeader.size(), fp);
 	fwrite(&bmpInfoHeader[0], sizeof(fk_ImType), bmpInfoHeader.size(), fp);
 
 	for(y = hSize-1; y >= 0; y--) {
 		MakeBmpBuffer(y, wSize, argTransFlg, &bmpBuffer[0]);
-		fwrite(&bmpBuffer[0], sizeof(fk_ImType), bitSize*wSize, fp);
+		fwrite(&bmpBuffer[0], sizeof(fk_ImType), bmpBufSize, fp);
 	}
 
 	fclose(fp);
