@@ -100,14 +100,40 @@ fk_IndexFaceSet::fk_IndexFaceSet(void)
 	type = FK_IF_NONE;
 	modifyFlg = true;
 	colorFlg = false;
-	anim = new fk_D3DXAnimation;
+	anim = NULL;
+	cloneFlg = false;
+	cloneList.clear();
+	orgIFS = NULL;
 
 	return;
 }
 
 fk_IndexFaceSet::~fk_IndexFaceSet()
 {
-	delete anim;
+	if(cloneFlg == true) {
+		orgIFS->cloneList.remove(this);
+	} else {
+		delete anim;
+	}
+
+	DeleteCloneLink(this);
+	return;
+}
+
+void fk_IndexFaceSet::DeleteCloneLink(fk_IndexFaceSet *argIFS)
+{
+	list<fk_IndexFaceSet *>::iterator	ite;
+
+	argIFS->anim = NULL;
+	argIFS->cloneFlg = false;
+	argIFS->orgIFS = NULL;
+
+	for(ite = argIFS->cloneList.begin();
+		ite != argIFS->cloneList.end(); ite++) {
+
+		DeleteCloneLink(*ite);
+	}
+	argIFS->cloneList.clear();
 	return;
 }
 
@@ -928,6 +954,9 @@ bool fk_IndexFaceSet::readD3DXFile(string argFileName, string argObjName,
 	fk_D3DXParser	*d3dxParser = new fk_D3DXParser();
 	bool			retFlg;
 
+	if(anim == NULL || cloneFlg == true) {
+		anim = new fk_D3DXAnimation;
+	}
 	d3dxParser->SetMeshData(this);
 	d3dxParser->SetAnimation(anim);
 	retFlg = d3dxParser->ReadD3DXFile(argFileName, argObjName,
@@ -1611,6 +1640,7 @@ void fk_IndexFaceSet::putSolid(fk_Solid *argSolid)
 
 fk_D3DXAnimation * fk_IndexFaceSet::GetAnimation(void)
 {
+	if(anim == NULL) anim = new fk_D3DXAnimation;
 	return anim;
 }
 
@@ -1618,6 +1648,8 @@ void fk_IndexFaceSet::setAnimationTime(double argTime)
 {
 	int		i;
 
+	if(anim == NULL) return;
+
 	if(pos.size() != timeOrgPos.size()) {
 		timeOrgPos = pos;
 	}
@@ -1633,6 +1665,43 @@ void fk_IndexFaceSet::setAnimationTime(double argTime)
 
 void fk_IndexFaceSet::setBVHMotion(fk_BVHMotion *argBVH)
 {
+	if(anim == NULL || cloneFlg == true) {
+		anim = new fk_D3DXAnimation;
+		cloneFlg = false;
+	}
 	anim->SetBVHMotion(argBVH);
 	return;
 }
+
+void fk_IndexFaceSet::cloneShape(fk_IndexFaceSet *argIFS)
+{
+	if(this == argIFS) return;
+	if(argIFS == NULL) return;
+
+	localPalette = argIFS->localPalette;
+	pos = argIFS->pos;
+	timeOrgPos = argIFS->timeOrgPos;
+	vNorm = argIFS->vNorm;
+	pNorm = argIFS->pNorm;
+	ifs = argIFS->ifs;
+	edgeSet = argIFS->edgeSet;
+	loopStack = argIFS->loopStack;
+	modifyFlg = argIFS->modifyFlg;
+	vNormFlg = argIFS->vNormFlg;
+	pNormFlg = argIFS->pNormFlg;
+	modifyList = argIFS->modifyList;
+	colorID = argIFS->colorID;
+	colorFlg = argIFS->colorFlg;
+	posSize = argIFS->posSize;
+	faceSize = argIFS->faceSize;
+	type = argIFS->type;
+
+	anim = argIFS->anim;
+	orgIFS = argIFS;
+	cloneFlg = true;
+
+	argIFS->cloneList.push_back(this);
+
+
+	return;
+}
