@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,10 +75,11 @@ fk_Light::fk_Light(fk_LightType argType)
 	: fk_Shape(FK_LIGHT)
 {
 	setLightType(argType);
-	Attenuation[0] = Attenuation[1] = 0.0;
-	SpotExponent = 0.0;
-	SpotCutOff = FK_PI/16.0;
-	setPaletteData(&localPal);
+	attenuation[0] = attenuation[1] = 0.0;
+	attenuation[2] = 1.0;
+	spotExponent = 0.0;
+	spotCutOff = FK_PI/16.0;
+	SetPaletteData(&localPal);
 
 	return;
 }
@@ -102,26 +101,27 @@ fk_LightType fk_Light::getLightType(void)
 	return lightType;
 }
 
-void fk_Light::setAttenuation(double argValue1, double argValue2)
+void fk_Light::setAttenuation(double argK_l, double argK_q, double argK_c)
 {
-	Attenuation[0] = (argValue1 < FK_EPS) ? 0.0 : argValue1;
-	Attenuation[1] = (argValue2 < FK_EPS) ? 0.0 : argValue2;
+	attenuation[0] = (argK_l < FK_EPS) ? 0.0 : argK_l;
+	attenuation[1] = (argK_q < FK_EPS) ? 0.0 : argK_q;
+	attenuation[2] = (argK_c < FK_EPS) ? 0.0 : argK_c;
 
 	return;
 }
 
 void fk_Light::setSpotExponent(double argExp)
 {
-	SpotExponent = (argExp < FK_EPS) ? 0.0 : argExp;
+	spotExponent = (argExp < FK_EPS) ? 0.0 : argExp;
 
 	return;
 }
 
 void fk_Light::setSpotCutOff(double argCurAngle)
 {
-	if(argCurAngle > FK_PI/2.0) SpotCutOff = FK_EPS;
-	else if(argCurAngle < FK_EPS) SpotCutOff = 0.0;
-	else SpotCutOff = argCurAngle;
+	if(argCurAngle > FK_PI/2.0) spotCutOff = FK_EPS;
+	else if(argCurAngle < FK_EPS) spotCutOff = 0.0;
+	else spotCutOff = argCurAngle;
 
 	return;
 }
@@ -131,7 +131,8 @@ double fk_Light::getAttenuation(int argIndex)
 	switch(argIndex) {
 	  case 0:
 	  case 1:
-		return Attenuation[argIndex];
+	  case 2:
+		return attenuation[argIndex];
 	  default:
 		break;
 	}
@@ -141,10 +142,10 @@ double fk_Light::getAttenuation(int argIndex)
 
 double fk_Light::getSpotExponent(void)
 {
-	return SpotExponent;
+	return spotExponent;
 }
 
 double fk_Light::getSpotCutOff(void)
 {
-	return SpotCutOff;
+	return spotCutOff;
 }
