@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,8 +73,8 @@
 #include "LineDraw_D3D.cxx"
 #else
 
-#include <FK/LineDraw.h>
-#include <FK/OpenGL.h>
+#include <FK/LineDraw.H>
+#include <FK/OpenGL.H>
 #include <FK/Model.h>
 #include <FK/Curve.h>
 #include <FK/Solid.h>
@@ -88,7 +86,7 @@ using namespace std;
 
 fk_LineDraw::fk_LineDraw(void)
 {
-	setArrayState(false);
+	SetArrayState(false);
 }
 
 fk_LineDraw::~fk_LineDraw()
@@ -96,13 +94,13 @@ fk_LineDraw::~fk_LineDraw()
 	return;
 }
 
-void fk_LineDraw::setArrayState(bool argState)
+void fk_LineDraw::SetArrayState(bool argState)
 {
 	arrayState = argState;
 	return;
 }
 
-void fk_LineDraw::drawShapeLine(fk_Model *argObj, bool argPickFlag)
+void fk_LineDraw::DrawShapeLine(fk_Model *argObj, bool argPickFlag)
 {
 	fk_MaterialMode	shapeMateMode;
 	fk_MaterialMode	modelMateMode;
