@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,7 +73,7 @@
 #include <FK/Half.h>
 #include <FK/Vertex.h>
 #include <FK/Math.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <list>
 #include <algorithm>
 
@@ -193,7 +191,6 @@ void fk_Loop::Init(int argID)
 {
 	InitTopology(argID, FK_LOOP_TYPE);
 	oneHalf = (fk_Half *)NULL;
-	shell = (fk_Shell *)NULL;
 	norm.set(0.0, 0.0, 0.0);
 	normFlag = errorFlag = tesselateFlag = false;
 	tesselateMode = true;
@@ -269,19 +266,6 @@ bool fk_Loop::SetNormal(void)
 	return true;
 }
 
-fk_Shell * fk_Loop::SetShell(fk_Shell *argS)
-{
-	fk_Shell *retS = shell;
-
-	shell = argS;
-	return retS;
-}
-
-fk_Shell * fk_Loop::GetShell(void) const
-{
-	return shell;
-}
-
 fk_Vector * fk_Loop::getNormal(void)
 {
 	if(errorFlag == true) return (fk_Vector *)NULL;
