@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,7 +71,7 @@
  ****************************************************************************/
 #include <FK/MatAdmin.h>
 #include <FK/Quaternion.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -143,7 +141,7 @@ fk_MatrixAdmin::~fk_MatrixAdmin()
 
 void fk_MatrixAdmin::UpdateMatrix(bool argAngFlag)
 {
-	fk_UnitMatrix	tmp1, tmp2;
+	fk_OrthoMatrix	tmp1, tmp2;
 
 	if(argAngFlag == true) {
 		AdjustVecToAngle();
@@ -152,18 +150,18 @@ void fk_MatrixAdmin::UpdateMatrix(bool argAngFlag)
 	tmp1.makeTrans(Position.x, Position.y, Position.z);
 	tmp2.makeEuler(Angle.h, Angle.p, Angle.b);
 
-	UnitaryMatrix = tmp1*tmp2;
+	OrthoMatrix = tmp1*tmp2;
 
 	return;
 }
 
-fk_UnitMatrix fk_MatrixAdmin::OrthonormalMatrix(const fk_Vector &argOrg,
+fk_OrthoMatrix fk_MatrixAdmin::OrthonormalMatrix(const fk_Vector &argOrg,
 												const fk_Vector &argTop,
 												const double argAngle) const
 {
 	fk_Vector		axis;
 	fk_Angle		ang;
-	fk_UnitMatrix	Trans, TransInv, Rot, RotInv;
+	fk_OrthoMatrix	Trans, TransInv, Rot, RotInv;
 
 	axis = argTop - argOrg;
 	Trans.makeTrans(-argOrg);
@@ -220,11 +218,16 @@ fk_Vector fk_MatrixAdmin::getVec(void) const
 	return Vec;
 }
 
-fk_Vector fk_MatrixAdmin::getUpVec(void) const
+fk_Vector fk_MatrixAdmin::getUpvec(void) const
 {
 	return UpVec;
 }
 
+fk_Vector fk_MatrixAdmin::getUpVec(void) const
+{
+	return getUpvec();
+}
+
 fk_Angle fk_MatrixAdmin::getAngle(void) const
 {
 	return Angle;
@@ -236,9 +239,9 @@ fk_Matrix fk_MatrixAdmin::getMatrix(void) const
 
 	if(ScaleMode == true) {
 		scaleMat.makeScale(Scale*xScale, Scale*yScale, Scale*zScale);
-		affineMat = UnitaryMatrix * scaleMat;
+		affineMat = OrthoMatrix * scaleMat;
 	} else {
-		affineMat = UnitaryMatrix;
+		affineMat = OrthoMatrix;
 	}
 
 	return affineMat;
@@ -249,9 +252,14 @@ fk_Matrix fk_MatrixAdmin::getInvMatrix(void) const
 	return (!getMatrix());
 }
 
-fk_UnitMatrix fk_MatrixAdmin::getBaseMatrix(void) const
+fk_OrthoMatrix fk_MatrixAdmin::getBaseMatrix(void) const
 {
-	return UnitaryMatrix;
+	return OrthoMatrix;
+}
+
+fk_OrthoMatrix fk_MatrixAdmin::getInvBaseMatrix(void) const
+{
+	return !OrthoMatrix;
 }
 
 bool fk_MatrixAdmin::setScale(const double argScale)
@@ -425,7 +433,7 @@ bool fk_MatrixAdmin::glRotate(fk_Vector argOrg, fk_Axis argAxis,
 	Rot.makeRot(argAngle, argAxis);
 
 	Position.ispos();
-	Position *= Trans * Rot * TransInv;
+	Position *= TransInv * Rot * Trans;
 	UpdateMatrix(false);
 
 	return true;
@@ -444,7 +452,7 @@ void fk_MatrixAdmin::GlRotate_(const fk_Vector &argOrg,
 							   const fk_Vector &argTop,
 							   double argAngle)
 {
-	fk_UnitMatrix rotMat = OrthonormalMatrix(argOrg, argTop, argAngle);
+	fk_OrthoMatrix rotMat = OrthonormalMatrix(argOrg, argTop, argAngle);
 
 	Position.ispos();
 	Position *= rotMat;
@@ -494,9 +502,9 @@ bool fk_MatrixAdmin::loRotate(fk_Vector argOrg, fk_Axis argAxis,
 
 	if(ScaleMode == true) {
 		scaleMat.makeScale(Scale*xScale, Scale*yScale, Scale*zScale);
-		affineMat = UnitaryMatrix * scaleMat;
+		affineMat = OrthoMatrix * scaleMat;
 	} else {
-		affineMat = UnitaryMatrix;
+		affineMat = OrthoMatrix;
 	}
 
 	SelfInv = !affineMat;
@@ -526,18 +534,18 @@ void fk_MatrixAdmin::LoRotate_(const fk_Vector &argOrg,
 							   const fk_Vector &argTop,
 							   double argAngle)
 {
-	fk_UnitMatrix	SelfInv;
-	fk_UnitMatrix	rotMat;
+	fk_OrthoMatrix	SelfInv;
+	fk_OrthoMatrix	rotMat;
 	fk_Matrix		scaleMat, affineMat;
 
 	if(ScaleMode == true) {
 		scaleMat.makeScale(Scale*xScale, Scale*yScale, Scale*zScale);
-		affineMat = UnitaryMatrix * scaleMat;
+		affineMat = OrthoMatrix * scaleMat;
 	} else {
-		affineMat = UnitaryMatrix;
+		affineMat = OrthoMatrix;
 	}
 
-	SelfInv = !UnitaryMatrix;
+	SelfInv = !OrthoMatrix;
 	rotMat = OrthonormalMatrix(argOrg, argTop, argAngle);
 	Position.ispos();
 	Position *= affineMat * rotMat * SelfInv;
@@ -666,16 +674,16 @@ bool fk_MatrixAdmin::glRotateWithVec(double argOX, double argOY, double argOZ,
 bool fk_MatrixAdmin::loRotateWithVec(fk_Vector argOrg, fk_Axis argAxis,
 									 double argAngle)
 {
-	fk_UnitMatrix SelfInv;
-	fk_UnitMatrix Rot, Trans, TransInv, New;
+	fk_OrthoMatrix SelfInv;
+	fk_OrthoMatrix Rot, Trans, TransInv, New;
 
-	SelfInv = !UnitaryMatrix;
+	SelfInv = !OrthoMatrix;
 	Trans.makeTrans(-argOrg);
 	TransInv.makeTrans(argOrg);
 
 	Rot.makeRot(argAngle, argAxis);
 
-	New = UnitaryMatrix * TransInv * Rot * Trans * SelfInv;
+	New = OrthoMatrix * TransInv * Rot * Trans * SelfInv;
 	Position.ispos();
 	Position *= New;
 
@@ -705,13 +713,13 @@ void fk_MatrixAdmin::LoRotateWithVec_(const fk_Vector &argOrg,
 									  const fk_Vector &argTop,
 									  double argAngle)
 {
-	fk_UnitMatrix rotMat;
-	fk_UnitMatrix SelfInv;
-	fk_UnitMatrix New;
+	fk_OrthoMatrix rotMat;
+	fk_OrthoMatrix SelfInv;
+	fk_OrthoMatrix New;
 
 	rotMat = OrthonormalMatrix(argOrg, argTop, argAngle);
-	SelfInv = !UnitaryMatrix;
-	New = UnitaryMatrix * rotMat * SelfInv;	
+	SelfInv = !OrthoMatrix;
+	New = OrthoMatrix * rotMat * SelfInv;	
 
 	Position.ispos();
 	Position *= New;
