@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,8 @@
  *
  ****************************************************************************/
 #include <FK/Material.h>
-#include <FK/Error.h>
+#include <FK/MatExample.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -351,6 +350,12 @@ int operator ==(fk_Material a, fk_Material b)
 		   a.specular == b.specular);
 }
 
+void fk_Material::initDefault(void)
+{
+	fk_InitMaterial();
+	return;
+}
+
 void fk_Material::Print(int argTabSize, string argTag)
 {
 	string		tab;
