@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/Matrix.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -93,7 +91,7 @@ inline bool AlmostEqual(double x, double y)
 }
 
 // 行列展開用関数 (retHVector = Mat*argHVector) 
-void fk_UnitMatrix::MultVec(fk_HVector &retHVector,
+void fk_OrthoMatrix::MultVec(fk_HVector &retHVector,
 							const fk_HVector &argHVector) const
 {
 	register int	i, j;
@@ -271,8 +269,8 @@ static bool fk_MatrixInverse(double mat[4][4])
 	return true;
 }
 
-// ユニタリー行列用逆行列演算 
-static void fk_UnitaryMatrixInverse(double mat[4][4])
+// 直交行列用逆行列演算 
+static void fk_OrthoMatrixInverse(double mat[4][4])
 {
 	double	t[3], tmp;
 	int		i, j;
@@ -354,31 +352,31 @@ static void MultMatrix(double m1[4][4],
 }
 
 
-////////// ユニタリー行列用メンバ関数群 
+////////// 直交行列用メンバ関数群 
 
 // コンストラクタ 
-fk_UnitMatrix::fk_UnitMatrix(void)
+fk_OrthoMatrix::fk_OrthoMatrix(void)
 {
 	MakeIdentMatrix(m);
 }
 
 // コピーコンストラクタ 
-fk_UnitMatrix::fk_UnitMatrix(const fk_UnitMatrix &ArgMat)
+fk_OrthoMatrix::fk_OrthoMatrix(const fk_OrthoMatrix &ArgMat)
 {
 	CopyMatrix(m, ArgMat.m);
 }
 
 // 初期化関数 (単位行列の生成) 
-void fk_UnitMatrix::init(void)
+void fk_OrthoMatrix::init(void)
 {
 	MakeIdentMatrix(m);
 	return;
 }
 
-void fk_UnitMatrix::set(int argR, int argC, double argValue)
+void fk_OrthoMatrix::set(int argR, int argC, double argValue)
 {
 	if(argR < 0 || argR > 3 || argC < 0 || argC > 3) {
-		fk_PutError("fk_UnitMatrix", "set", 1, "ID Error");
+		fk_PutError("fk_OrthoMatrix", "set", 1, "ID Error");
 		return;
 	}
 
@@ -387,13 +385,13 @@ void fk_UnitMatrix::set(int argR, int argC, double argValue)
 }
 
 
-bool fk_UnitMatrix::inverse(void)
+bool fk_OrthoMatrix::inverse(void)
 {
-	fk_UnitaryMatrixInverse(m);
+	fk_OrthoMatrixInverse(m);
 	return true;
 }
 
-void fk_UnitMatrix::negate(void)
+void fk_OrthoMatrix::negate(void)
 {
 	register int	i, j;
 	double			tmp;
@@ -409,7 +407,7 @@ void fk_UnitMatrix::negate(void)
 	return;
 }
 
-void fk_UnitMatrix::makeRot(double Angle, fk_Axis Axis)
+void fk_OrthoMatrix::makeRot(double Angle, fk_Axis Axis)
 {
 	MakeIdentMatrix(m);
 
@@ -438,7 +436,7 @@ void fk_UnitMatrix::makeRot(double Angle, fk_Axis Axis)
 	return;
 }
 
-void fk_UnitMatrix::makeTrans(double x, double y, double z)
+void fk_OrthoMatrix::makeTrans(double x, double y, double z)
 {
 	MakeIdentMatrix(m);
 
@@ -449,7 +447,7 @@ void fk_UnitMatrix::makeTrans(double x, double y, double z)
 	return;
 }
 
-void fk_UnitMatrix::makeTrans(const fk_Vector &Vec)
+void fk_OrthoMatrix::makeTrans(const fk_Vector &Vec)
 {
 	MakeIdentMatrix(m);
 
@@ -461,9 +459,9 @@ void fk_UnitMatrix::makeTrans(const fk_Vector &Vec)
 }
 
 
-void fk_UnitMatrix::makeEuler(double h, double p, double b)
+void fk_OrthoMatrix::makeEuler(double h, double p, double b)
 {
-	fk_UnitMatrix	hM, pM, bM;
+	fk_OrthoMatrix	hM, pM, bM;
 
 	hM.makeRot(-h, fk_Y);
 	pM.makeRot(p, fk_X);
@@ -474,13 +472,13 @@ void fk_UnitMatrix::makeEuler(double h, double p, double b)
 	return;
 }
 
-void fk_UnitMatrix::makeEuler(const fk_Angle &argAngle)
+void fk_OrthoMatrix::makeEuler(const fk_Angle &argAngle)
 {
 	makeEuler(argAngle.h, argAngle.p, argAngle.b);
 	return;
 }
 
-void fk_UnitMatrix::Print(string str) const
+void fk_OrthoMatrix::Print(string str) const
 {
 	register int	i;
 
@@ -497,21 +495,21 @@ void fk_UnitMatrix::Print(string str) const
 	return;
 }
 
-fk_UnitMatrix fk_UnitMatrix::operator !(void) const
+fk_OrthoMatrix fk_OrthoMatrix::operator !(void) const
 {
-	fk_UnitMatrix	ret;
+	fk_OrthoMatrix	ret;
 	ret = *this;
 	ret.inverse();
 	return ret;
 }
 
-double * fk_UnitMatrix::operator [](int index)
+double * fk_OrthoMatrix::operator [](int index)
 {
 	return m[index];
 }
 
 // 比較演算子 
-bool fk_UnitMatrix::operator ==(const fk_UnitMatrix &Mat) const
+bool fk_OrthoMatrix::operator ==(const fk_OrthoMatrix &Mat) const
 {
 	register int i, j;
 
@@ -524,7 +522,7 @@ bool fk_UnitMatrix::operator ==(const fk_UnitMatrix &Mat) const
 	return true;
 }
 
-bool fk_UnitMatrix::operator !=(const fk_UnitMatrix &Mat) const
+bool fk_OrthoMatrix::operator !=(const fk_OrthoMatrix &Mat) const
 {
 	register int i, j;
 
@@ -538,15 +536,15 @@ bool fk_UnitMatrix::operator !=(const fk_UnitMatrix &Mat) const
 }
 
 // 代入演算子 
-fk_UnitMatrix & fk_UnitMatrix::operator =(const fk_UnitMatrix &ArgMat)
+fk_OrthoMatrix & fk_OrthoMatrix::operator =(const fk_OrthoMatrix &ArgMat)
 {
 	CopyMatrix(m, ArgMat.m);
 	return *this;
 }
 
-fk_UnitMatrix & fk_UnitMatrix::operator *=(const fk_UnitMatrix &ArgMat)
+fk_OrthoMatrix & fk_OrthoMatrix::operator *=(const fk_OrthoMatrix &ArgMat)
 {
-	fk_UnitMatrix tmp;
+	fk_OrthoMatrix tmp;
 
 	MultMatrix(tmp.m, m, ArgMat.m);
 	CopyMatrix(m, tmp.m);
@@ -554,7 +552,7 @@ fk_UnitMatrix & fk_UnitMatrix::operator *=(const fk_UnitMatrix &ArgMat)
 	return *this;
 }
 
-fk_Vector & fk_Vector::operator *=(const fk_UnitMatrix &argMat)
+fk_Vector & fk_Vector::operator *=(const fk_OrthoMatrix &argMat)
 {
 	fk_HVector	tmp1, tmp2;
 	tmp1 = *this;
@@ -563,7 +561,7 @@ fk_Vector & fk_Vector::operator *=(const fk_UnitMatrix &argMat)
 	return *this;
 }
 
-fk_HVector & fk_HVector::operator *=(const fk_UnitMatrix &argMat)
+fk_HVector & fk_HVector::operator *=(const fk_OrthoMatrix &argMat)
 {
 	fk_HVector	tmp = *this;
 	argMat.MultVec(*this, tmp);
@@ -571,7 +569,7 @@ fk_HVector & fk_HVector::operator *=(const fk_UnitMatrix &argMat)
 }
 
 // 二項演算子 
-fk_HVector operator *(const fk_UnitMatrix &Mat, const fk_HVector &Vec)
+fk_HVector operator *(const fk_OrthoMatrix &Mat, const fk_HVector &Vec)
 {
 	fk_HVector Ret;
 
@@ -580,9 +578,9 @@ fk_HVector operator *(const fk_UnitMatrix &Mat, const fk_HVector &Vec)
 	return Ret;
 }
 
-fk_UnitMatrix operator *(const fk_UnitMatrix &m1, const fk_UnitMatrix &m2)
+fk_OrthoMatrix operator *(const fk_OrthoMatrix &m1, const fk_OrthoMatrix &m2)
 {
-	fk_UnitMatrix Ret;
+	fk_OrthoMatrix Ret;
 
 	MultMatrix(Ret.m, m1.m, m2.m);
 
@@ -600,7 +598,7 @@ fk_Matrix::fk_Matrix(void)
 
 // コピーコンストラクタ 
 fk_Matrix::fk_Matrix(const fk_Matrix &argMat)
-	: fk_UnitMatrix()
+	: fk_OrthoMatrix()
 {
 	CopyMatrix(m, argMat.m);
 }
@@ -672,7 +670,7 @@ fk_Matrix & fk_Matrix::operator =(const fk_Matrix &ArgMat)
 	return *this;
 }
 
-fk_Matrix & fk_Matrix::operator =(const fk_UnitMatrix &ArgMat)
+fk_Matrix & fk_Matrix::operator =(const fk_OrthoMatrix &ArgMat)
 {
 	CopyMatrix(m, ArgMat.m);
 	return *this;
@@ -684,7 +682,7 @@ fk_Matrix & fk_Matrix::operator +=(const fk_Matrix &ArgMat)
 	return *this;
 }
 
-fk_Matrix & fk_Matrix::operator +=(const fk_UnitMatrix &ArgMat)
+fk_Matrix & fk_Matrix::operator +=(const fk_OrthoMatrix &ArgMat)
 {
 	AddMatrix(m, ArgMat.m);
 	return *this;
@@ -696,7 +694,7 @@ fk_Matrix & fk_Matrix::operator -=(const fk_Matrix &ArgMat)
 	return *this;
 }
 
-fk_Matrix & fk_Matrix::operator -=(const fk_UnitMatrix &ArgMat)
+fk_Matrix & fk_Matrix::operator -=(const fk_OrthoMatrix &ArgMat)
 {
 	SubMatrix(m, ArgMat.m);
 	return *this;
@@ -712,7 +710,7 @@ fk_Matrix & fk_Matrix::operator *=(const fk_Matrix &ArgMat)
 	return *this;
 }
 
-fk_Matrix & fk_Matrix::operator *=(const fk_UnitMatrix &ArgMat)
+fk_Matrix & fk_Matrix::operator *=(const fk_OrthoMatrix &ArgMat)
 {
 	fk_Matrix tmp;
 
@@ -757,7 +755,7 @@ fk_Matrix operator +(const fk_Matrix &m1, const fk_Matrix &m2)
 	return Ret;
 }
 
-fk_Matrix operator +(const fk_Matrix &m1, const fk_UnitMatrix &m2)
+fk_Matrix operator +(const fk_Matrix &m1, const fk_OrthoMatrix &m2)
 {
 	fk_Matrix Ret;
 
@@ -767,7 +765,7 @@ fk_Matrix operator +(const fk_Matrix &m1, const fk_UnitMatrix &m2)
 	return Ret;
 }
 
-fk_Matrix operator +(const fk_UnitMatrix &m1, const fk_Matrix &m2)
+fk_Matrix operator +(const fk_OrthoMatrix &m1, const fk_Matrix &m2)
 {
 	fk_Matrix Ret;
 
@@ -787,7 +785,7 @@ fk_Matrix operator -(const fk_Matrix &m1, const fk_Matrix &m2)
 	return Ret;
 }
 
-fk_Matrix operator -(const fk_Matrix &m1, const fk_UnitMatrix &m2)
+fk_Matrix operator -(const fk_Matrix &m1, const fk_OrthoMatrix &m2)
 {
 	fk_Matrix Ret;
 
@@ -797,7 +795,7 @@ fk_Matrix operator -(const fk_Matrix &m1, const fk_UnitMatrix &m2)
 	return Ret;
 }
 
-fk_Matrix operator -(const fk_UnitMatrix &m1, const fk_Matrix &m2)
+fk_Matrix operator -(const fk_OrthoMatrix &m1, const fk_Matrix &m2)
 {
 	fk_Matrix Ret;
 
@@ -816,7 +814,7 @@ fk_Matrix operator *(const fk_Matrix &m1, const fk_Matrix &m2)
 	return Ret;
 }
 
-fk_Matrix operator *(const fk_Matrix &m1, const fk_UnitMatrix &m2)
+fk_Matrix operator *(const fk_Matrix &m1, const fk_OrthoMatrix &m2)
 {
 	fk_Matrix Ret;
 
@@ -825,7 +823,7 @@ fk_Matrix operator *(const fk_Matrix &m1, const fk_UnitMatrix &m2)
 	return Ret;
 }
 
-fk_Matrix operator *(const fk_UnitMatrix &m1, const fk_Matrix &m2)
+fk_Matrix operator *(const fk_OrthoMatrix &m1, const fk_Matrix &m2)
 {
 	fk_Matrix Ret;
 
