@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,15 +70,15 @@
  *
  ****************************************************************************/
 #include <FK/Texture.h>
-#include <FK/MQOParser.h>
-#include <FK/Error.h>
+#include <FK/MQOParser.H>
+#include <FK/Error.H>
 
 using namespace std;
 
 fk_MeshTexture::fk_MeshTexture(fk_Image *argImage)
 	: fk_Texture(argImage)
 {
-	setObjectType(FK_MESHTEXTURE);
+	SetObjectType(FK_MESHTEXTURE);
 	triNum = 0;
 	posArray.clear();
 	coordArray.clear();
@@ -370,7 +368,7 @@ bool fk_MeshTexture::readMQOFile(string argFileName, string argObjName,
 {
 	fk_MQOParser		mqoParser;
 
-	mqoParser.setMeshTexture(this);
-	mqoParser.setContMode(argContFlg);
-	return mqoParser.readMQOFile(argFileName, argObjName, -1, true);
+	mqoParser.SetMeshTexture(this);
+	mqoParser.SetContMode(argContFlg);
+	return mqoParser.ReadMQOFile(argFileName, argObjName, -1, true);
 }
