@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/Model.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <FK/Tree.h>
 
 using namespace std;
@@ -312,6 +310,6 @@ fk_Model * fk_Model::foreachChild(fk_Model *argModel)
 
 void fk_Model::TreePrint(void)
 {
-	_modelTree.print();
+	_modelTree.Print();
 	return;
 }
