@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,8 +75,7 @@
 #include <FK/Half.h>
 #include <FK/Edge.h>
 #include <FK/Loop.h>
-#include <FK/Shell.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -1723,7 +1720,7 @@ void fk_Operation::RedoCom(fk_Command *argCom)
 	return;
 }
 
-void fk_Operation::printHistorySize(void)
+void fk_Operation::PrintHistorySize(void)
 {
 	history.PrintSize();
 	return;
@@ -1741,7 +1738,7 @@ void fk_Operation::setTesselateMode(bool argMode)
 			curL->isTesselated();
 		}
 	} else {
-		deleteAllTesselateData();
+		DeleteAllTesselateData();
 	}
 
 	return;
@@ -1752,7 +1749,7 @@ bool fk_Operation::getTesselateMode(void)
 	return tesselateMode;
 }
 
-void fk_Operation::deleteAllTesselateData(void)
+void fk_Operation::DeleteAllTesselateData(void)
 {
 	fk_Loop			*curL;
 
