@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -73,14 +71,14 @@
  ****************************************************************************/
 #include <FK/Particle.h>
 #include <FK/Point.h>
-#include <FK/IDAdmin.h>
+#include <FK/IDAdmin.H>
 #include <FK/Shape.h>
 
 using namespace std;
 
 fk_Particle::fk_Particle(fk_Point *argBase, int argID)
 {
-	setObjectType(FK_PARTICLE);
+	SetObjectType(FK_PARTICLE);
 	base = argBase;
 	id = argID;
 	init();
@@ -201,7 +199,7 @@ void fk_Particle::handle(void)
 
 fk_ParticleSet::fk_ParticleSet(unsigned int argMax)
 {
-	setObjectType(FK_PARTICLESET);
+	SetObjectType(FK_PARTICLESET);
 	pAdmin = new fk_IDAdmin;
 	pAdmin->Init(0);
 	point = new fk_Point;
