@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,8 +75,8 @@ using namespace std;
 
 fk_Point::fk_Point(vector<fk_Vector> *argVertexSet)
 {
-	setObjectType(FK_POINT);
-	setPaletteData(&localPal);
+	SetObjectType(FK_POINT);
+	SetPaletteData(&localPal);
 	allClear(false);
 	MakePoint(argVertexSet);
 	return;
