@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/Projection.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 fk_ProjectBase::fk_ProjectBase(fk_ProjectMode argMode)
 {
@@ -91,15 +89,19 @@ void fk_ProjectBase::SetMode(fk_ProjectMode argMode)
 
 	switch(Mode) {
 	  case FK_NONE_PROJ_MODE:
-		setObjectType(FK_PROJECTBASE);
+		SetObjectType(FK_PROJECTBASE);
 		break;
 
 	  case FK_PERSPECTIVE_MODE:
-		setObjectType(FK_PERSPECTIVE);
+		SetObjectType(FK_PERSPECTIVE);
+		break;
+
+	  case FK_FRUSTUM_MODE:
+		SetObjectType(FK_FRUSTUM);
 		break;
 
 	  case FK_ORTHO_MODE:
-		setObjectType(FK_ORTHO);
+		SetObjectType(FK_ORTHO);
 		break;
 
 	  default:
@@ -199,6 +201,117 @@ double fk_Perspective::getFar(void) const
 	return Far;
 }
 
+fk_Frustum::fk_Frustum(double argLeft, double argRight,
+					   double argBottom, double argTop,
+					   double argNear, double argFar)
+	: fk_ProjectBase(FK_FRUSTUM_MODE)
+{
+	setAll(argLeft, argRight, argBottom, argTop, argNear, argFar);
+	return;
+}
+
+fk_Frustum::fk_Frustum(const fk_Frustum &argFrustum)
+	: fk_ProjectBase(FK_FRUSTUM_MODE)
+{
+	setAll(argFrustum.Left, argFrustum.Right,
+		   argFrustum.Bottom, argFrustum.Top,
+		   argFrustum.Near, argFrustum.Far);
+}
+
+fk_Frustum::~fk_Frustum()
+{
+	return;
+}
+
+fk_Frustum & fk_Frustum::operator =(const fk_Frustum &argFrustum)
+{
+	SetMode(FK_FRUSTUM_MODE);
+	setAll(argFrustum.Left, argFrustum.Right,
+		   argFrustum.Bottom, argFrustum.Top,
+		   argFrustum.Near, argFrustum.Far);
+
+	return *this;
+}
+
+void fk_Frustum::setLeft(double argLeft)
+{
+	Left = argLeft;
+	return;
+}
+
+void fk_Frustum::setRight(double argRight)
+{
+	Right = argRight;
+	return;
+}
+
+void fk_Frustum::setBottom(double argBottom)
+{
+	Bottom = argBottom;
+	return;
+}
+
+void fk_Frustum::setTop(double argTop)
+{
+	Top = argTop;
+	return;
+}
+
+void fk_Frustum::setNear(double argNear)
+{
+	Near = argNear;
+	return;
+}
+
+void fk_Frustum::setFar(double argFar)
+{
+	Far = argFar;
+	return;
+}
+
+void fk_Frustum::setAll(double argLeft, double argRight,
+						double argBottom, double argTop,
+						double argNear, double argFar)
+{
+	Left = argLeft;
+	Right = argRight;
+	Bottom = argBottom;
+	Top = argTop;
+	Near = argNear;
+	Far = argFar;
+	return;
+}
+
+double fk_Frustum::getLeft(void) const
+{
+	return Left;
+}
+
+double fk_Frustum::getRight(void) const
+{
+	return Right;
+}
+
+double fk_Frustum::getBottom(void) const
+{
+	return Bottom;
+}
+
+double fk_Frustum::getTop(void) const
+{
+	return Top;
+}
+
+double fk_Frustum::getNear(void) const
+{
+	return Near;
+}
+
+double fk_Frustum::getFar(void) const
+{
+	return Far;
+}
+
 fk_Ortho::fk_Ortho(double argLeft, double argRight,
 				   double argBottom, double argTop,
 				   double argNear, double argFar)
