@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,8 +69,8 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/Quaternion.h>
-#include <FK/Error.h>
+#include <FK/Math.h>
+#include <FK/Error.H>
 
 static fk_Angle & VectorToHeadPitch(const fk_Vector &argVec)
 {
@@ -166,7 +164,7 @@ fk_Quaternion::fk_Quaternion(const fk_Quaternion &argQ)
 
 void fk_Quaternion::init(void)
 {
-	set(0.0, 0.0, 0.0, 0.0);
+	set(1.0, 0.0, 0.0, 0.0);
 	return;
 }
 
@@ -461,45 +459,12 @@ double operator ^(const fk_Quaternion &argQ1, const fk_Quaternion &argQ2)
 fk_Quaternion & fk_Q_Inter_Linear(const fk_Quaternion &argQ1,
 								  const fk_Quaternion &argQ2, double argT)
 {
-	static fk_Quaternion q;
-
-	q = (1.0 - argT) * argQ1 + argT * argQ2;
-	q.normalize();
-	return q;
+	return fk_Math::quatInterLinear(argQ1, argQ2, argT);
 }
 
 fk_Quaternion & fk_Q_Inter_Sphere(const fk_Quaternion &argQ1,
 								  const fk_Quaternion &argQ2, double argT)
 {
-	static fk_Quaternion	q1, q2, q3;
-	double					theta, sinTheta, prod;
-
-	q1 = argQ1;
-
-	if((argQ1 == argQ2) || (argQ1 == -argQ2)) return q1;
-
-	if((argQ1 ^ argQ2) >= 0.0) {
-		q2 = argQ2;
-	} else {
-		q2 = -argQ2;
-	}
-
-	q1.normalize();
-	q2.normalize();
-
-	prod = q1 ^ q2;
-	if(prod > 1.0) prod = 1.0;
-	if(prod < -1.0) prod = -1.0;
-
-	theta = acos(prod);
-	sinTheta = sin(theta);
-	if(fabs(sinTheta) < FK_VECTOREPS) {
-		q3 = fk_Q_Inter_Linear(argQ1, argQ2, argT);
-	} else {
-		q3 = (sin(theta * (1.0 - argT))/sinTheta) * q1
-			+ (sin(theta*argT)/sinTheta) * q2;
-	}
-
-	return q3;
+	return fk_Math::quatInterSphere(argQ1, argQ2, argT);
 }
 
