@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,7 +69,7 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/STLOut.h>
+#include <FK/STLOut.H>
 #include <FK/Solid.h>
 #include <FK/IndexFace.h>
 #include <FK/Vertex.h>
@@ -100,7 +98,7 @@ fk_STLOut::~fk_STLOut()
 	return;
 }
 
-bool fk_STLOut::writeSTLFile(string argFileName)
+bool fk_STLOut::WriteSTLFile(string argFileName)
 {
 	FILE		*writeFP;
 	bool		retFlg;
