@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,7 +69,7 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/STLParser.h>
+#include <FK/STLParser.H>
 #include <FK/HeapBase.h>
 
 using namespace std;
@@ -86,7 +84,7 @@ fk_STLParser::~fk_STLParser()
 	return;
 }
 
-bool fk_STLParser::readSTLFile(string argFileName, bool argSolidFlag, double)
+bool fk_STLParser::ReadSTLFile(string argFileName, bool argSolidFlag, double)
 {
 	FILE					*stlFP;
 	vector<fk_Vector>		VecSet;
