@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -77,7 +75,7 @@ using namespace std;
 
 fk_Shape::fk_Shape(fk_ObjectType argObjType)
 {
-	setObjectType(argObjType);
+	SetObjectType(argObjType);
 	materialMode = FK_NONE_MODE;
 	return;
 }
@@ -87,12 +85,18 @@ fk_Shape::~fk_Shape()
 	return;
 }
 
-void fk_Shape::setPaletteData(fk_Palette *argPal)
+void fk_Shape::SetPaletteData(fk_Palette *argPal)
 {
 	palette = argPal;
 	return;
 }
 
+void fk_Shape::setPaletteData(fk_Palette *argPal)
+{
+	SetPaletteData(argPal);
+	return;
+}
+
 fk_Palette * fk_Shape::getPaletteData(void)
 {
 	return palette;
@@ -104,12 +108,14 @@ void fk_Shape::clearMaterial(void)
 	return;
 }
 
+/*
 void fk_Shape::setObjMaterial(fk_Material &argMat)
 {
 	palette->setObjMaterial(&argMat);
 	materialMode = FK_CHILD_MODE;
 	return;
 }
+*/
 
 void fk_Shape::setObjMaterialID(int argID)
 {
@@ -143,10 +149,12 @@ fk_MaterialMode fk_Shape::getMaterialMode(void)
 	return materialMode;
 }
 
+/*
 fk_Material * fk_Shape::getObjMaterial(void)
 {
 	return palette->getObjMaterial();
 }
+*/
 
 int fk_Shape::getObjMaterialID(void)
 {
