@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -75,12 +73,12 @@
 #include "TextureDraw_D3D.cxx"
 #else
 
-#include <FK/TextureDraw.h>
+#include <FK/TextureDraw.H>
 #include <FK/IFSTexture.h>
 #include <FK/Model.h>
-#include <FK/FaceDraw.h>
+#include <FK/FaceDraw.H>
 
-#include <FK/Error.h>
+#include <FK/Error.H>
 #include <algorithm>
 
 using namespace std;
@@ -89,24 +87,24 @@ vector<GLuint>	fk_TextureDraw::texNameArray;
 
 fk_TextureDraw::fk_TextureDraw(void)
 {
-	setArrayState(false);
-	setBindMode(false);
+	SetArrayState(false);
+	SetBindMode(false);
 	oldTexID = 0;
 }
 
 fk_TextureDraw::~fk_TextureDraw()
 {
-	clearTextureMemory();
+	ClearTextureMemory();
 	return;
 }
 
-void fk_TextureDraw::setArrayState(bool argState)
+void fk_TextureDraw::SetArrayState(bool argState)
 {
 	arrayState = argState;
 	return;
 }
 
-void fk_TextureDraw::startUp(void)
+void fk_TextureDraw::StartUp(void)
 {
 	string		str;
 
@@ -114,7 +112,7 @@ void fk_TextureDraw::startUp(void)
 	return;
 }
 
-void fk_TextureDraw::drawTextureObj(fk_Model *argObj, bool argLightFlag, bool argPickFlag)
+void fk_TextureDraw::DrawTextureObj(fk_Model *argObj, bool argLightFlag, bool argPickFlag)
 {
 	fk_Texture	*texObj;
 	int			mateID = -2;
@@ -166,9 +164,9 @@ void fk_TextureDraw::drawTextureObj(fk_Model *argObj, bool argLightFlag, bool ar
 	}
 
 	if(mateID == FK_UNDEFINED) {
-		fk_FaceDraw::commonMateSet(argObj, argLightFlag, true);
+		fk_FaceDraw::CommonMateSet(argObj, argLightFlag, true);
 	} else {
-		fk_FaceDraw::localMateSet(texObj->getMaterial(mateID), argLightFlag);
+		fk_FaceDraw::LocalMateSet(texObj->getMaterial(mateID), argLightFlag);
 	}
 
 	// (必要なら)テクスチャオブジェクトの生成 
@@ -536,7 +534,7 @@ void fk_TextureDraw::ReplaceTextureObj(fk_Texture *argTexObj)
 	return;
 }
 
-void fk_TextureDraw::clearTextureMemory(void)
+void fk_TextureDraw::ClearTextureMemory(void)
 {
 	if(texNameArray.empty() == false) {
 		glDeleteTextures(GLsizei(texNameArray.size()), &texNameArray[0]);
@@ -559,6 +557,10 @@ void fk_TextureDraw::InitTextureEnv(fk_Texture *argTexObj)
 		texMode = GL_MODULATE;
 		break;
 
+	  case FK_TEX_DECAL:
+		texMode = GL_DECAL;
+		break;
+
 	  default:
 		break;
 	}
@@ -567,7 +569,7 @@ void fk_TextureDraw::InitTextureEnv(fk_Texture *argTexObj)
 
 	if(bindMode == false || curID != oldTexID) {
 		glEnable(GL_TEXTURE_2D);
-		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, (GLfloat)texMode);
+		glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, texMode);
 		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
 		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
 		glBindTexture(GL_TEXTURE_2D, curID);
@@ -578,13 +580,13 @@ void fk_TextureDraw::InitTextureEnv(fk_Texture *argTexObj)
 	return;
 }
 
-void fk_TextureDraw::setBindMode(bool argFlg)
+void fk_TextureDraw::SetBindMode(bool argFlg)
 {
 	bindMode = argFlg;
 	return;
 }
 
-bool fk_TextureDraw::getBindMode(void)
+bool fk_TextureDraw::GetBindMode(void)
 {
 	return bindMode;
 }
