@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -137,7 +135,7 @@ bool fk_Topology::CloneElem(fk_Topology *argTP)
 	if(ID == FK_UNDEFINED) return false;
 	return true;
 }
-
+/*
 void fk_Topology::setAriveMark(void)
 {
 	ariveFlg = true;
@@ -148,6 +146,7 @@ bool fk_Topology::getAriveMark(void)
 {
 	return ariveFlg;
 }
+*/
 
 ////////////////////////////////////////////////////////////////////////
 
@@ -184,18 +183,6 @@ int fk_TopologyMaterial::getElemMaterialID(void)
 	return mateID;
 }
 
-void fk_TopologyMaterial::setObjMaterialMode(fk_MaterialMode argMode)
-{
-	setElemMaterialMode(argMode);
-	return;
-}
-
-void fk_TopologyMaterial::setObjMaterialID(int argID)
-{
-	setElemMaterialID(argID);
-	return;
-}
-
 void fk_TopologyMaterial::CloneMaterial(fk_TopologyMaterial *argMat)
 {
 	mateMode = argMat->mateMode;
