@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,13 +69,13 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/VRMLOut.h>
+#include <FK/VRMLOut.H>
 #include <FK/Vertex.h>
 #include <FK/Loop.h>
 #include <FK/Solid.h>
 #include <FK/IndexFace.h>
 #include <FK/Material.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -103,7 +101,7 @@ fk_VRMLOut::~fk_VRMLOut()
 	return;
 }
 
-bool fk_VRMLOut::writeVRMLFile(string argFileName, fk_Material *argMaterial,
+bool fk_VRMLOut::WriteVRMLFile(string argFileName, fk_Material *argMaterial,
 							   bool triFlag)
 {
 	FILE		*writeFP;
@@ -126,7 +124,7 @@ bool fk_VRMLOut::writeVRMLFile(string argFileName, fk_Material *argMaterial,
 	return true;
 }
 
-bool fk_VRMLOut::writeVRMLFile(string argFileName,
+bool fk_VRMLOut::WriteVRMLFile(string argFileName,
 							   vector<double> *argTime,
 							   vector<fk_Vector> *argPos,
 							   fk_Material *argMaterial,
@@ -161,8 +159,6 @@ void fk_VRMLOut::WriteVRMLShape(FILE *argFP,
 								vector<double> *argTime,
 								vector<fk_Vector> *argPos)
 {
-	string	outStr;
-
 	WriteVRMLLightInfo(argFP);
 	WriteVRMLNaviInfo(argFP);
 
@@ -171,9 +167,7 @@ void fk_VRMLOut::WriteVRMLShape(FILE *argFP,
 		WriteVRMLCoordInterp(argFP, argTime, argPos);
 	}
 
-	outStr = "\t\tShape {\n";
-
-	fprintf(argFP, outStr.c_str());
+	fprintf(argFP, "\t\tShape {\n");
 
 	WriteVRMLMaterial(argFP, argMaterial);
 	if(solid != (fk_Solid *)NULL) {
@@ -184,11 +178,10 @@ void fk_VRMLOut::WriteVRMLShape(FILE *argFP,
 		WriteVRMLIFData_IFS(argFP, triFlag);
 	}
 
-	outStr = "\t\t\t\tcolorPerVertex TRUE\n";
-	outStr += "\t\t\t\tconvex TRUE\n";
-	outStr += "\t\t\t}\n";
-	outStr += "\t\t}\n";
-	fprintf(argFP, outStr.c_str());
+	fprintf(argFP, "\t\t\t\tcolorPerVertex TRUE\n");
+	fprintf(argFP, "\t\t\t\tconvex TRUE\n");
+	fprintf(argFP, "\t\t\t}\n");
+	fprintf(argFP, "\t\t}\n");
 
 	return;
 }
@@ -230,15 +223,12 @@ void fk_VRMLOut::WriteVRMLNaviInfo(FILE *argFP)
 
 void fk_VRMLOut::WriteVRMLMaterial(FILE *argFP, fk_Material *argMaterial)
 {
-	string		outStr;
 	fk_Color	*curColor;
 
 	if(argMaterial == (fk_Material *)NULL) return;
 
-	outStr = "\t\t\tappearance Appearance {\n";
-	outStr += "\t\t\t\tmaterial Material {\n";
-
-	fprintf(argFP, outStr.c_str());
+	fprintf(argFP, "\t\t\tappearance Appearance {\n");
+	fprintf(argFP, "\t\t\t\tmaterial Material {\n");
 
 	// Ambient
 	curColor = argMaterial->getAmbient();
@@ -274,14 +264,12 @@ void fk_VRMLOut::WriteVRMLPointData_Solid(FILE *argFP)
 {
 	fk_Vertex		*curV;
 	fk_Vector		pos;
-	string			outStr;
 
 	curV = solid->getNextV((fk_Vertex *)NULL);
 
-	outStr = "\t\t\tgeometry IndexedFaceSet {\n";
-	outStr += "\t\t\t\tcoord DEF C Coordinate {\n";
-	outStr += "\t\t\t\t\tpoint [\n";
-	fprintf(argFP, outStr.c_str());
+	fprintf(argFP, "\t\t\tgeometry IndexedFaceSet {\n");
+	fprintf(argFP, "\t\t\t\tcoord DEF C Coordinate {\n");
+	fprintf(argFP, "\t\t\t\t\tpoint [\n");
 
 	while(curV != (fk_Vertex *)NULL) {
 
@@ -296,9 +284,8 @@ void fk_VRMLOut::WriteVRMLPointData_Solid(FILE *argFP)
 		fprintf(argFP, "\n");
 	}
 
-	outStr = "\t\t\t\t\t]\n";
-	outStr += "\t\t\t\t}\n";
-	fprintf(argFP, outStr.c_str());
+	fprintf(argFP, "\t\t\t\t\t]\n");
+	fprintf(argFP, "\t\t\t\t}\n");
 
 	return;
 }
@@ -306,13 +293,11 @@ void fk_VRMLOut::WriteVRMLPointData_Solid(FILE *argFP)
 void fk_VRMLOut::WriteVRMLPointData_IFS(FILE *argFP)
 {
 	fk_Vector		pos;
-	string			outStr;
 	int				i, pSize;
 
-	outStr = "\t\t\tgeometry IndexedFaceSet {\n";
-	outStr += "\t\t\t\tcoord DEF C Coordinate {\n";
-	outStr += "\t\t\t\t\tpoint [\n";
-	fprintf(argFP, outStr.c_str());
+	fprintf(argFP, "\t\t\tgeometry IndexedFaceSet {\n");
+	fprintf(argFP, "\t\t\t\tcoord DEF C Coordinate {\n");
+	fprintf(argFP, "\t\t\t\t\tpoint [\n");
 
 	pSize = ifs->getPosSize();
 	for(i = 0; i < pSize; i++) {
@@ -326,9 +311,8 @@ void fk_VRMLOut::WriteVRMLPointData_IFS(FILE *argFP)
 		fprintf(argFP, "\n");
 	}
 
-	outStr = "\t\t\t\t\t]\n";
-	outStr += "\t\t\t\t}\n";
-	fprintf(argFP, outStr.c_str());
+	fprintf(argFP, "\t\t\t\t\t]\n");
+	fprintf(argFP, "\t\t\t\t}\n");
 
 	return;
 }
@@ -427,7 +411,7 @@ void fk_VRMLOut::WriteVRMLIFData_IFS(FILE *argFP, bool)
 
 void fk_VRMLOut::WriteVRMLFooter(FILE *argFP, fk_VRMLOutMode argMode)
 {
-	string outStr, tab;
+	string 	outStr, tab;
 
 	outStr.erase();
 
@@ -449,7 +433,7 @@ void fk_VRMLOut::WriteVRMLFooter(FILE *argFP, fk_VRMLOutMode argMode)
 		outStr += "ROUTE TS.fraction_changed TO CI.set_fraction\n";
 	}
 
-	fprintf(argFP, outStr.c_str());
+	fwrite(outStr.c_str(), sizeof(char), outStr.size(), argFP);
 	return;
 }
 
@@ -472,7 +456,7 @@ void fk_VRMLOut::WriteVRMLCoordInterp(FILE *argFP,
 
 	tab = baseTab + "\t";
 	buf += tab + "key [\n";
-	fprintf(argFP, buf.c_str());
+	fwrite(buf.c_str(), sizeof(char), buf.size(), argFP);
 
 	tab = baseTab + "\t\t";
 	for(i = 0; i < int(argTime->size()); i++) {
@@ -482,13 +466,13 @@ void fk_VRMLOut::WriteVRMLCoordInterp(FILE *argFP,
 			buf += ",";
 		}
 		buf += "\n";
-		fprintf(argFP, buf.c_str());
+		fwrite(buf.c_str(), sizeof(char), buf.size(), argFP);
 	}
 
 	tab = baseTab + "\t";
 	buf = tab + "]\n";
 	buf += tab + "keyValue [\n";
-	fprintf(argFP, buf.c_str());
+	fwrite(buf.c_str(), sizeof(char), buf.size(), argFP);
 
 	tab = baseTab + "\t\t";
 	for(i = 0; i < int(argPos->size()); i++) {
@@ -499,14 +483,14 @@ void fk_VRMLOut::WriteVRMLCoordInterp(FILE *argFP,
 			buf += ",";
 		}
 		buf += "\n";
-		fprintf(argFP, buf.c_str());
+		fwrite(buf.c_str(), sizeof(char), buf.size(), argFP);
 	}
 
 	tab = baseTab + "\t";
 	buf = tab + "]\n";
 	tab = baseTab;
 	buf += tab + "}\n";
-	fprintf(argFP, buf.c_str());
+	fwrite(buf.c_str(), sizeof(char), buf.size(), argFP);
 
 	return;
 }
