@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -71,7 +69,7 @@
  *	ついて、一切責任を負わないものとします。
  *
  ****************************************************************************/
-#include <FK/VRMLParser.h>
+#include <FK/VRMLParser.H>
 
 using namespace std;
 
@@ -85,7 +83,7 @@ fk_VRMLParser::~fk_VRMLParser()
 	return;
 }
 
-bool fk_VRMLParser::readVRMLFile(string argFileName,
+bool fk_VRMLParser::ReadVRMLFile(string argFileName,
 								 bool argMaterialFlag, bool argSolidFlag)
 {
 	FILE					*vrmlFP;
