@@ -1,7 +1,6 @@
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	Redistribution and use in source and binary forms,
  *	with or without modification, are permitted provided that the
@@ -37,8 +36,7 @@
  ****************************************************************************/
 /****************************************************************************
  *
- *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
- *	Tokyo University of Technology, All rights reserved.
+ *	Copyright (c) 1999-2009, Fine Kernel Project, All rights reserved.
  *
  *	本ソフトウェアおよびソースコードのライセンスは、基本的に
  *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
@@ -72,7 +70,7 @@
  *
  ****************************************************************************/
 #include <FK/Vector.h>
-#include <FK/Error.h>
+#include <FK/Error.H>
 
 using namespace std;
 
@@ -617,14 +615,3 @@ fk_Vector operator ^(const fk_Vector &a, const fk_Vector &b)
 				  a.x * b.y - a.y * b.x);
 	return(tmp);
 }
-
-double fk_CalcCosine(fk_Vector pos1, fk_Vector pos2)
-{
-	if(pos1.normalize() == false || pos2.normalize() == false) {
-		fk_PutError("Function", "fk_CalcCosine", 1, "Zero Vector Error");
-		return 0.0;
-	}
-
-	return(pos1*pos2);
-}
-
